<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" 
xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
xmlns:xs="http://www.w3.org/2001/XMLSchema" 
xmlns:fn="http://www.w3.org/2005/xpath-functions"
xmlns:rwe="http://www.rwe.com/gi/ada"
exclude-result-prefixes="xs fn rwe">
	<xsl:output method="xml" version="1.0" encoding="ISO-8859-1" indent="yes"/>
	
	<xsl:variable name="now" select="current-dateTime()"/>
	<xsl:variable name="nachrichtennummer"
	select="concat('A', format-dateTime($now,
		'[Y02][M01][D01][H01][m01][s01]'), substring(format-dateTime($now, '[f01]'), 1, 1))"/>


		<!-- Default-Regel: alles unterdrücken -->
	<xsl:template match="* | @* | text()">
		<xsl:message terminate="yes">
			<xsl:text>Unberücksichtigt: </xsl:text>
			<xsl:for-each select="ancestor::node()">
				<xsl:value-of select="name()"/>
				<xsl:text>/</xsl:text>
			</xsl:for-each>
			<xsl:value-of select="name()"/>
		</xsl:message>
	</xsl:template>

	
	<xsl:template match="/">
		<xsl:copy>
			<xsl:apply-templates select="*" mode="copy"/>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="/*" mode="copy">
		<xsl:copy>
			<xsl:call-template name="IDs"/>
			<xsl:apply-templates select="S_UNB" mode="copy"/>
			<xsl:apply-templates select="M_MSCONS22/G_MSCONS22_SG2/S_NAD[D_3035='MS']" mode="copy"/>
			<xsl:apply-templates select="M_MSCONS22/G_MSCONS22_SG2/S_NAD[D_3035='MR']" mode="copy"/>
			<AperakFehler>
				<xsl:choose>
					<xsl:when test="name() = 'EDIFACTINTERCHANGE'">
						<xsl:apply-templates select="."/>
					</xsl:when>
					<xsl:otherwise>
						<unb>
							<code>Z08</code>
							<freitext>Datei ist leer</freitext>
						</unb>
					</xsl:otherwise>
				</xsl:choose>
			</AperakFehler>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template name="IDs">
		<IDs>
			<now>
				<xsl:value-of select="$now"/>
			</now>
			<nachrichtennummer>
				<xsl:value-of select="$nachrichtennummer"/>
			</nachrichtennummer>
			<nowFormatted>
				<xsl:value-of select="format-dateTime ($now, '[Y02][M01][D01]:[H01][m01]')"/>
			</nowFormatted>
			<nowDTM>
				<xsl:value-of select="format-dateTime($now, '[Y0002][M01][D01][H01][m01]')"/>
			</nowDTM>
		</IDs>
	</xsl:template>
	
	<xsl:template match="* | @* | text()" mode="copy">
		<xsl:copy>
			<xsl:apply-templates select="* | @* | text()" mode="copy"/>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="EDIFACTINTERCHANGE">
		<xsl:choose>
			<xsl:when test="S_UNB">
				<xsl:apply-templates select="S_UNB"/>
			
			
				<!-- Nachrichten prüfen -->
				<xsl:apply-templates select="M_MSCONS22"/>
			</xsl:when>
			<xsl:otherwise>
				<unb>
					<code>Z03</code>
					<freitext>Segment UNB fehlt</freitext>
				</unb>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<!-- *****                                                                            *****  -->
	<!-- *****                     Übertragung (UNB) prüfen                               *****  -->
	<!-- *****                                                                            *****  -->
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_UNB">
		<!-- C_S001/D_0001 muss existieren und 'UNOC' lauten -->
		<xsl:call-template name="unbValue">
			<xsl:with-param name="knoten" select="C_S001/D_0001"/>
			<xsl:with-param name="wert" select="'UNOC'"/>
			<xsl:with-param name="path" select="'UNB/S001/D0001'"/>
		</xsl:call-template>
		
		<!-- C_S001/D_0002 muss existieren und '3' lauten -->
		<xsl:call-template name="unbValue">
			<xsl:with-param name="knoten" select="C_S001/D_0002"/>
			<xsl:with-param name="wert" select="'3'"/>
			<xsl:with-param name="path" select="'UNB/S001/D0002'"/>
		</xsl:call-template>
		
		<!-- C_S002/D_0007 muss existieren und einen gültigen Eintrag aus einer Liste von Werten haben -->
		<xsl:call-template name="unbList">
			<xsl:with-param name="knoten" select="C_S002/D_0007"/>
			<xsl:with-param name="path" select="'UNB/S002/D0007'"/>
			<xsl:with-param name="list" select="'14,500,501,502,ZZZ'"/>
		</xsl:call-template>
		
		<!-- C_S003/D_0007 muss existieren und einen gültigen Eintrag aus einer Liste von Werten haben -->
		<xsl:call-template name="unbList">
			<xsl:with-param name="knoten" select="C_S003/D_0007"/>
			<xsl:with-param name="path" select="'UNB/S003/D0007'"/>
			<xsl:with-param name="list" select="'14,500,501,502,ZZZ'"/>
		</xsl:call-template>
			
		<!-- C_S004/D_0017 muss ein gültiges Datumsformat sein -->
		<xsl:call-template name="unbIsDate">
			<xsl:with-param name="knoten" select="C_S004/D_0017"/>
			<xsl:with-param name="path" select="'UNB/S004/D0017'"/>
		</xsl:call-template>
		
		<!-- C_S004/D_0019 muss ein gültiges Zeitformat sein -->
		<xsl:call-template name="unbIsTime">
			<xsl:with-param name="knoten" select="C_S004/D_0019"/>
			<xsl:with-param name="path" select="'UNB/S004/D0019'"/>
		</xsl:call-template>
		
		<!-- D_0026 muss, sofern vorhanden, aus einer Liste stammen -->
		<xsl:call-template name="unbList">
			<xsl:with-param name="knoten" select="D_0026"/>
			<xsl:with-param name="path" select="'UNB/D0026'"/>
			<xsl:with-param name="required" select="false()"/>
			<xsl:with-param name="list" select="'LG,EM,VL,TL'"/>
		</xsl:call-template>
		
		<!-- D_0032 muss, sofern vorhanden, DISI lauten -->
		<xsl:call-template name="unbValue">
			<xsl:with-param name="knoten" select="D_0032"/>
			<xsl:with-param name="path" select="'UNB/D0032'"/>
			<xsl:with-param name="required" select="false()"/>
			<xsl:with-param name="wert" select="'DISI'"/>
		</xsl:call-template>
	</xsl:template>

	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<!-- *****                                                                            *****  -->
	<!-- *****                     Nachrichten (UNHs) prüfen                              *****  -->
	<!-- *****                                                                            *****  -->
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_MSCONS22">
		<xsl:variable name="nachrichtID" select="S_UNH/D_0062" />
		<xsl:apply-templates select="descendant::node()[substring(name(), 1, 2) = 'S_']">
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
		<xsl:apply-templates select="." mode="Absender">
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
		<xsl:apply-templates select="." mode="Empfaenger">
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           Marktpartner (Absender) prüfen                                   *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_MSCONS22" mode="Absender">
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="G_MSCONS22_SG2/S_NAD[D_3035='MS']">
				<xsl:apply-templates select="G_MSCONS22_SG2/S_NAD[D_3035='MS']" mode="Absender">
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z08</code>
					<freitext>Segment SG1/NAD fuer Absender fehlt</freitext>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
					<segment>0</segment>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="G_MSCONS22_SG2/S_NAD[D_3035='MS']" mode="Absender">
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C082/D_3039"/>
			<xsl:with-param name="path" select="'SG1/NAD/C082/3039 fuer Qualifier MS'"/>
			<xsl:with-param name="segment" select="0"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           Marktpartner (Empfänger) prüfen                                  *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_MSCONS22" mode="Empfaenger">
		<xsl:param name="nachrichtID"/>

		<xsl:choose>
			<xsl:when test="G_MSCONS22_SG2/S_NAD[D_3035='MR']">
				<xsl:apply-templates select="G_MSCONS22_SG2/S_NAD[D_3035='MR']" mode="Empfaenger">
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z08</code>
					<freitext>Segment SG1/NAD fuer Empfaenger fehlt</freitext>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
					<segment>0</segment>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="G_MSCONS22_SG2/S_NAD[D_3035='MR']" mode="Empfaenger">
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C082/D_3039"/>
			<xsl:with-param name="path" select="'SG1/NAD/C082/3039 fuer Qualifier MR'"/>
			<xsl:with-param name="segment" select="0"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           UNH prüfen                                                       *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_UNH">
		<xsl:param name="nachrichtID"/>
		<xsl:variable name="segment" select="position()"/>
		
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_S009"/>
			<xsl:with-param name="path" select="'UNH/S009'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="D_0062"/>
			<xsl:with-param name="path" select="'UNH/D0062'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

		<xsl:apply-templates select="C_S009">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template match="S_UNH/C_S009">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0065"/>
			<xsl:with-param name="wert" select="'MSCONS'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0065'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0052"/>
			<xsl:with-param name="wert" select="'D'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0052'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0054"/>
			<xsl:with-param name="wert" select="'04B'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0054'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0051"/>
			<xsl:with-param name="wert" select="'UN'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0051'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0057"/>
			<xsl:with-param name="wert" select="'2.2b'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0057'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
	</xsl:template>

	<!-- **************************************************************************************  -->
	<!-- *****            S_BGM prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_BGM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>

		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C002/D_1001"/>
			<xsl:with-param name="path" select="'BGM/C0002/1001'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'7,BK,Z06,Z15,Z16,Z20'"/>
		</xsl:call-template>

		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C106/D_1004"/>
			<xsl:with-param name="path" select="'BGM/C106/1004'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		

		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_1225"/>
			<xsl:with-param name="path" select="'BGM/1225'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'1,9'"/>
		</xsl:call-template>

		<!-- für ein Storno muss die Referenz mit angegeben sein. -->
		<xsl:if test="D_1225='1'">
			<xsl:choose>
				<xsl:when test="string-length(../G_MSCONS22_SG1/S_RFF/C_C506/D_1153) &gt; 0"/>
				<xsl:otherwise>
					<unh>
						<code>Z03</code>
						<freitext>SG1/RFF/C504/1153 fehlt fuer ein Storno</freitext>
						<segment>
							<xsl:value-of select="$segment"/>
						</segment>
						<referenz>
							<xsl:value-of select="$nachrichtID"/>
						</referenz>
					</unh>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	

	<!-- **************************************************************************************  -->
	<!-- *****            S_DTM unter MSCONS-Wurzel prüfen                                *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_MSCONS22/S_DTM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C507/D_2005"/>
			<xsl:with-param name="path" select="'DTM/C507/2005'"/>
			<xsl:with-param name="list" select="'137'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="required" select="false()"/>
		</xsl:call-template>
	
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C507/D_2380"/>
			<xsl:with-param name="path" select="'DTM/C507/2380'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C507/D_2379"/>
			<xsl:with-param name="path" select="'DTM/C507/2379'"/>
			<xsl:with-param name="list" select="'203'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:apply-templates select="C_C507" mode="validateFormat">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
	</xsl:template>

	<!-- **************************************************************************************  -->
	<!-- *****            S_DTM in Segmentgruppe SG1 prüfen                               *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_MSCONS22_SG1/S_DTM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="C_C507/D_2005"/>
			<xsl:with-param name="path" select="'SG1/DTM/C507/2005'"/>
			<xsl:with-param name="wert" select="'171'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C507/D_2380"/>
			<xsl:with-param name="path" select="'DTM/C507/2380'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="C_C507/D_2379"/>
			<xsl:with-param name="path" select="'SG1/DTM/C507/2379'"/>
			<xsl:with-param name="wert" select="'203'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:apply-templates select="C_C507" mode="validateFormat">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
	</xsl:template>



	<!-- **************************************************************************************  -->
	<!-- *****            S_RFF in Segmentgruppe 1 prüfen                                 *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_MSCONS22_SG1/S_RFF">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C506/D_1153"/>
			<xsl:with-param name="list" select="'AGI,ACW'"/>
			<xsl:with-param name="path" select="'SG1/RFF/1153'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C506/D_1154"/>
			<xsl:with-param name="path" select="'SG1/RFF/1154'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
	</xsl:template>

	
	<!-- **************************************************************************************  -->
	<!-- *****           S_NAD unter der zweiten Segmentgruppe prüfen                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_MSCONS22_SG2/S_NAD">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_3035"/>
			<xsl:with-param name="path" select="'SG2/NAD/3035'"/>
			<xsl:with-param name="list" select="'MS,MR'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C082/D_3055_1"/>
			<xsl:with-param name="path" select="'SG2/NAD/C082/3055'"/>
			<xsl:with-param name="list" select="'9,293,305,321,332'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_CTA prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_CTA">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>

		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_3139"/>
			<xsl:with-param name="wert" select="'IC'"/>
			<xsl:with-param name="path" select="'SG1/SG2/CTA/3139'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C056/D_3412"/>
			<xsl:with-param name="path" select="'SG1/SG2/CTA/C056/3412'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_COM prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_COM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C076/D_3155"/>
			<xsl:with-param name="path" select="'SG1/SG2/COM/C076/3511'"/>
			<xsl:with-param name="list" select="'TE,EM,AJ,AL,FX'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_UNS prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_UNS">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>

		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0081"/>
			<xsl:with-param name="wert" select="'D'"/>
			<xsl:with-param name="path" select="'UNS/0081'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_NAD in Segmentgruppe 5 prüfen                                  *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_MSCONS22_SG5/S_NAD">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>

		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_3035"/>
			<xsl:with-param name="path" select="'SG5/NAD/3035'"/>
			<xsl:with-param name="list" select="'DP,DED,Z15'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_LOC prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_MSCONS22_SG5/G_MSCONS22_SG6/S_LOC">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>

		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_3227"/>
			<xsl:with-param name="path" select="'SG5/SG6/LOC/3227'"/>
			<xsl:with-param name="list" select="'172,Z04,107,237,Z06'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C517/D_3225"/>
			<xsl:with-param name="path" select="'SG5/SG6/LOC/C517/3225'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

		<xsl:choose>
			<xsl:when test="D_3227='237'">
				<xsl:call-template name="unhRequired">
					<xsl:with-param name="knoten" select="C_C519/D_3223"/>
					<xsl:with-param name="path" select="'SG5/SG6/LOC/C519/3223'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C517/D_3055_1"/>
					<xsl:with-param name="wert" select="'305'"/>
					<xsl:with-param name="path" select="'SG5/SG6/LOC/C517/3055'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>	
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C517/D_3055_1"/>
					<xsl:with-param name="path" select="'SG5/SG6/LOC/C517/3055'"/>
					<xsl:with-param name="list" select="'89,305'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>	
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****            S_DTM in Segmentgruppe SG6 prüfen                              *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_MSCONS22_SG5/G_MSCONS22_SG6/S_DTM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C507/D_2005"/>
			<xsl:with-param name="path" select="'SG5/SG6/DTM/C507/2005'"/>
			<xsl:with-param name="list" select="'163,164,672,492,293,9'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C507/D_2380"/>
			<xsl:with-param name="path" select="'SG5/SG6/DTM/C507/2380'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C507/D_2379"/>
			<xsl:with-param name="path" select="'SG5/SG6/DTM/C507/2379'"/>
			<xsl:with-param name="list" select="'102,303,806,610,204'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:apply-templates select="C_C507">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
		
		<xsl:apply-templates select="C_C507" mode="validateFormat">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template match="G_MSCONS22_SG5/G_MSCONS22_SG6/S_DTM/C_C507">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="
					(D_2005='163' and D_2379='303') 
				or	(D_2005='163' and D_2379='102') 
				or	(D_2005='164' and D_2379='303')
				or	(D_2005='164' and D_2379='102')
				or	(D_2005='672' and D_2379='806')
				or	(D_2005='293' and D_2379='204')
				or	(D_2005='9' and D_2379='303')
				or	(D_2005='9' and D_2379='102')
				or	(D_2005='492' and D_2379='610')"/>
			<xsl:otherwise>
				<unh>
					<code>Z01</code>
					<freitext>
						<xsl:text>Feld SG5/SG6/DTM/C507: falsches Datenformat </xsl:text>
						<xsl:value-of select="D_2379"/>
						<xsl:text> fuer Datumsqualifier </xsl:text>
						<xsl:value-of select="D_2005"/>
					</freitext>
					<segment><xsl:value-of select = "$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_RFF in Segmentgruppe 7 prüfen                                  *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_MSCONS22_SG7/S_RFF">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>

		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="C_C506/D_1153"/>
			<xsl:with-param name="path" select="'SG5/SG6/SG7/RFF/C506/1153'"/>
			<xsl:with-param name="wert" select="'MG'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C506/D_1154"/>
			<xsl:with-param name="path" select="'SG5/SG6/SG7/RFF/C506/1154'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>

	
	<!-- **************************************************************************************  -->
	<!-- *****           S_CCI in Segmentgruppe 8 prüfen                                  *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_MSCONS22_SG8/S_CCI">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>

		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_7059"/>
			<xsl:with-param name="path" select="'SG5/SG6/SG8/7059'"/>
			<xsl:with-param name="list" select="'ACH,10,16,15'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C240/D_7037"/>
			<xsl:with-param name="path" select="'SG5/SG6/SG8/C240/7037'"/>
			<xsl:with-param name="list" select="'COM,IOM,ROM,COS,COB,CMP,PMR,COT,SMV,EMV,MRV,WS,SW,BI1,BI2,BI3,GAA,GAB,GAC,GE1,GE2,GE3,SO1,SO2,SO3,WF1,WF2,WF3,WN1,WN2,WN3,WAA,WAB,WAC'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_LIN prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_MSCONS22_SG9/S_LIN">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>

		<xsl:call-template name="unhInteger">
			<xsl:with-param name="knoten" select="D_1082"/>
			<xsl:with-param name="path" select="'SG5/SG6/SG9/LIN/1082'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_PIA prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_MSCONS22_SG9/S_PIA">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>

		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_4347"/>
			<xsl:with-param name="path" select="'SG5/SG6/SG9/PIA/4347'"/>
			<xsl:with-param name="wert" select="'5'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C212_1/D_7140_1"/>
			<xsl:with-param name="path" select="'SG5/SG6/SG9/PIA/C212/7140'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C212_1/D_7143_1"/>
			<xsl:with-param name="path" select="'SG5/SG6/SG9/PIA/C212/7143'"/>
			<xsl:with-param name="list" select="'SRW,Z02'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_QTY prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_MSCONS22_SG9/G_MSCONS22_SG10/S_QTY">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>

		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C186/D_6063"/>
			<xsl:with-param name="path" select="'SG5/SG6/SG9/SG10/QTY/C186/6064'"/>
			<xsl:with-param name="list" select="'220,67,201,20,187,79'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C186/D_6060"/>
			<xsl:with-param name="path" select="'SG5/SG6/SG9/SG10/QTY/C186/6060'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		<xsl:apply-templates select="C_C186/D_6060">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C186/D_6411"/>
			<xsl:with-param name="path" select="'SG5/SG6/SG9/SG10/QTY/C186/6411'"/>
			<xsl:with-param name="list" select="'KWH,KWT,KAH,KVR'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="required" select="false()"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="G_MSCONS22_SG9/G_MSCONS22_SG10/S_QTY/C_C186/D_6060">
		<xsl:param name="segment" as="xs:integer"/>
		<xsl:param name="nachrichtID"/>
		<xsl:variable name="trimmed" select="normalize-space(.)"/>
		<xsl:if test="string-length($trimmed) &gt; 0">
			<xsl:variable name="komma2punkt" select="translate($trimmed, ',', '.')"/>
			<xsl:choose>
				<xsl:when test="$komma2punkt castable as xs:double"/>
				<xsl:otherwise>
					<unh>
						<code>Z02</code>
						<freitext>
							<xsl:text>SG5/SG6/SG9/SG10/QTY/C186/6060 ist keine gebrochene Zahl:</xsl:text>
							<xsl:value-of select="."/>
						</freitext>
						<segment><xsl:value-of select = "$segment"/></segment>
						<referenz><xsl:value-of select="$nachrichtID"/></referenz>
					</unh>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>

	<!-- **************************************************************************************  -->
	<!-- *****            S_DTM in Segmentgruppe SG10 prüfen                              *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_MSCONS22_SG9/G_MSCONS22_SG10/S_DTM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C507/D_2005"/>
			<xsl:with-param name="path" select="'SG9/SG10/DTM/C507/2005'"/>
			<xsl:with-param name="list" select="'9,163,164'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C507/D_2380"/>
			<xsl:with-param name="path" select="'SG9/SG10/DTM/C507/2380'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C507/D_2379"/>
			<xsl:with-param name="path" select="'SG9/SG10/DTM/C507/2379'"/>
			<xsl:with-param name="list" select="'102,303'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:apply-templates select="C_C507">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
		
		<xsl:apply-templates select="C_C507" mode="validateFormat">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template match="G_MSCONS22_SG9/G_MSCONS22_SG10/S_DTM/C_C507">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="
					(D_2005='163' and (D_2379='303' or D_2379='102')) 
				or	(D_2005='164' and (D_2379='303' or D_2379='102'))
				or	(D_2005='9' and D_2379='303')
				or	(D_2005='9' and D_2379='102')"/>
			<xsl:otherwise>
				<unh>
					<code>Z01</code>
					<freitext>
						<xsl:text>Feld SG9/SG10/DTM/C507: falsches Datenformat </xsl:text>
						<xsl:value-of select="D_2379"/>
						<xsl:text> fuer Datumsqualifier </xsl:text>
						<xsl:value-of select="D_2005"/>
					</freitext>
					<segment><xsl:value-of select = "$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<!-- **************************************************************************************  -->
	<!-- *****            S_STS in Segmentgruppe SG10 prüfen                              *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_MSCONS22_SG9/G_MSCONS22_SG10/S_STS">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C601/D_9015"/>
			<xsl:with-param name="path" select="'SG9/SG10/STS/C601/9015'"/>
			<xsl:with-param name="list" select="'6,8'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:if test="C_C555">
			<xsl:call-template name="unhList">
				<xsl:with-param name="knoten" select="C_C555/D_4405"/>
				<xsl:with-param name="path" select="'SG9/SG10/STS/C555/4405'"/>
				<xsl:with-param name="list" select="'T1,T2,T3,T4,T5,T6,T7,T8,T9'"/>
				<xsl:with-param name="segment" select="$segment"/>
				<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			</xsl:call-template>
			
			<xsl:call-template name="unhValue">
				<xsl:with-param name="knoten" select="C_C555/D_1131"/>
				<xsl:with-param name="path" select="'SG9/SG10/STS/C555/1131'"/>
				<xsl:with-param name="wert" select="'108'"/>
				<xsl:with-param name="segment" select="$segment"/>
				<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			</xsl:call-template>
		</xsl:if>
		
		<xsl:if test="C_C556">
			<xsl:call-template name="unhList">
				<xsl:with-param name="knoten" select="C_C556/D_9013"/>
				<xsl:with-param name="path" select="'SG9/SG10/STS/C556/9013'"/>
				<xsl:with-param name="list" >
					<xsl:text>ZA2,Z83,ZC0,Z84,Z85,Z86,Z87,ZC3,Z88,Z89,Z90,Z91,Z92,Z93,Z94,</xsl:text>
					<xsl:text>Z95,Z96,Z97,Z74,Z75,Z76,Z77,Z78,Z79,Z80,Z81,Z82,Z98,Z99,</xsl:text>
					<xsl:text>ZA0,Za1,ZC2,ZA3,ZA4,ZA5,ZA6,ZA7,ZA8,ZA9,ZB0,ZB9</xsl:text>
				</xsl:with-param>
				<xsl:with-param name="segment" select="$segment"/>
				<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	
	<!-- **************************************************************************************  -->
	<!-- *****           diese Segmente bleiben ungeprüft                                 *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_UNT"/>


	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<!-- *****                                                                            *****  -->
	<!-- *****                     Validierung von Datumsformaten                         *****  -->
	<!-- *****                                                                            *****  -->
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_DTM/C_C507[D_2379='303']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 14">
				<xsl:variable name="zeitzone1" select="substring(D_2380, 13)"/>
				<xsl:variable name="zeitzone">
					<xsl:choose>
						<xsl:when test="substring($zeitzone1, 1, 1) = '?'">
							<xsl:value-of select="substring($zeitzone1, 2)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$zeitzone1"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 7, 2)"/>
					<xsl:text>T</xsl:text>
					<xsl:value-of select="substring(D_2380, 9, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring(D_2380, 11, 2)"/>
					<xsl:text>:00.000</xsl:text>
					<xsl:value-of select="$zeitzone"/>
					<xsl:text>:00</xsl:text>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:dateTime"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>
								<xsl:text>Feld DTM/C507/2380 entspricht nicht dem Datumsformat</xsl:text>
								<xsl:text> 303 - CCYYMMDDHHMMZZZ: </xsl:text>
								<xsl:value-of select="D_2380"/>
							</freitext>
							<segment><xsl:value-of select = "$segment"/></segment>
							<referenz><xsl:value-of select="$nachrichtID"/></referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 203 - CCYYMMDDHHMMZZZ</freitext>
					<segment><xsl:value-of select = "$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
		
	<xsl:template match="S_DTM/C_C507[D_2379='203']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 11">
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 7, 2)"/>
					<xsl:text>T</xsl:text>
					<xsl:value-of select="substring(D_2380, 9, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring(D_2380, 11, 2)"/>
					<xsl:text>:00.000</xsl:text>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:dateTime"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 203 - CCYYMMDDHHMM</freitext>
							<segment><xsl:value-of select = "$segment"/></segment>
							<referenz><xsl:value-of select="$nachrichtID"/></referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 203 - CCYYMMDDHHMM</freitext>
					<segment><xsl:value-of select = "$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
		
	<xsl:template match="S_DTM/C_C507[D_2379='204']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 13">
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 7, 2)"/>
					<xsl:text>T</xsl:text>
					<xsl:value-of select="substring(D_2380, 9, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring(D_2380, 11, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring(D_2380, 13, 2)"/>
					<xsl:text>.000</xsl:text>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:dateTime"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 204 - CCYYMMDDHHMMSS</freitext>
							<segment><xsl:value-of select = "$segment"/></segment>
							<referenz><xsl:value-of select="$nachrichtID"/></referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 204 - CCYYMMDDHHMMSS</freitext>
					<segment><xsl:value-of select = "$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
		
	<xsl:template match="S_DTM/C_C507[D_2379='102']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 7">
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 7, 2)"/>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:date"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 102 - CCYYMMDD</freitext>
							<segment><xsl:value-of select = "$segment"/></segment>
							<referenz><xsl:value-of select="$nachrichtID"/></referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 102 - CCYYMMDD</freitext>
					<segment><xsl:value-of select = "$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
		
	<xsl:template match="S_DTM/C_C507[D_2379='806']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 0">
				<xsl:choose>
					<xsl:when test="D_2380 castable as xs:integer">
						<xsl:variable name="asInt" as="xs:integer" select="D_2380"/>
						<xsl:if test="$asInt &lt; 0 or $asInt &gt; 59">
							<unh>
								<code>Z02</code>
								<freitext>
									<xsl:text>Feld DTM/C507/2380 ist keine Minute: </xsl:text>
									<xsl:value-of select="$asInt"/>
								</freitext>
								<segment><xsl:value-of select = "$segment"/></segment>
								<referenz><xsl:value-of select="$nachrichtID"/></referenz>
							</unh>
						</xsl:if>
					</xsl:when>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 806 - Minuten</freitext>
							<segment><xsl:value-of select = "$segment"/></segment>
							<referenz><xsl:value-of select="$nachrichtID"/></referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 806 - Minuten</freitext>
					<segment><xsl:value-of select = "$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
		
	<xsl:template match="S_DTM/C_C507[D_2379='610']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 5">
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-01</xsl:text>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:date"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 610 - CCYYMM</freitext>
							<segment><xsl:value-of select = "$segment"/></segment>
							<referenz><xsl:value-of select="$nachrichtID"/></referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 610 - CCYYMM</freitext>
					<segment><xsl:value-of select = "$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="S_DTM/C_C507" mode="validateFormat" priority="5">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:message terminate="yes">
			<xsl:text>Unberücksichtigtes Format in "validateFormat": </xsl:text>
			<xsl:value-of select="D_2379"/>
			<xsl:text> in Referenz </xsl:text>
			<xsl:value-of select="$nachrichtID"/>
			<xsl:text> Segment </xsl:text>
			<xsl:value-of select="$segment"/>
		</xsl:message>
	</xsl:template>


	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<!-- *****                                                                            *****  -->
	<!-- *****                     Transformations-Funktionen                             *****  -->
	<!-- *****                                                                            *****  -->
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<xsl:template name="unbValue">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="wert" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="required" required="no" as="xs:boolean" select="true()"/>
		
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="$knoten != $wert">
					<unb>
						<code>Z01</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> muss </xsl:text>
							<xsl:value-of select="$wert"/>
							<xsl:text> lauten, ist aber </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
					</unb>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$required">
					<xsl:call-template name="unbRequired">
						<xsl:with-param name="knoten" select="$knoten"/>
						<xsl:with-param name="path" select="$path"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="unbList">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="list" required="yes" as="xs:string"/>
		<xsl:param name="required" required="no" as="xs:boolean" select="true()"/>
		
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="not(exists(tokenize($list, ',')[. = $knoten]))">
					<unb>
						<code>Z01</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> muss </xsl:text>
							<xsl:value-of select="$list"/>
							<xsl:text> lauten, ist aber </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
					</unb>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$required">
					<xsl:call-template name="unbRequired">
						<xsl:with-param name="knoten" select="$knoten"/>
						<xsl:with-param name="path" select="$path"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="unbRequired">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:if test="not($knoten)">
			<unb>
				<code>Z03</code>
				<freitext>
					<xsl:text>Feld </xsl:text>
					<xsl:value-of select="$path"/>
					<xsl:text> fehlt</xsl:text>
				</freitext>
			</unb>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="unbIsDate">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:variable name="formatted">
					<xsl:text>20</xsl:text>
					<xsl:value-of select="substring($knoten, 1, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring($knoten, 3, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring($knoten, 5, 2)"/>
				</xsl:variable>
				<xsl:if test="not($formatted castable as xs:date)">
					<unb>
						<code>Z02</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> entspricht nicht dem Datumsformat YYMMDD: </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
					</unb>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="unbRequired">
					<xsl:with-param name="knoten" select="$knoten"/>
					<xsl:with-param name="path" select="$path"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="unbIsTime">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:variable name="formatted">
					<xsl:value-of select="substring($knoten, 1, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring($knoten, 3, 2)"/>
					<xsl:text>:00</xsl:text>
				</xsl:variable>
				<xsl:if test="not($formatted castable as xs:time)">
					<unb>
						<code>Z02</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> entspricht nicht dem Zeitformat HHMM: </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
					</unb>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="unbRequired">
					<xsl:with-param name="knoten" select="$knoten"/>
					<xsl:with-param name="path" select="$path"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="unhValue">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="wert" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="required" required="no" as="xs:boolean" select="true()"/>
		<xsl:param name="segment" as="xs:integer" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="$knoten != $wert">
					<unh>
						<code>Z01</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> muss </xsl:text>
							<xsl:value-of select="$wert"/>
							<xsl:text> lauten, ist aber </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
						<segment><xsl:value-of select="$segment"/></segment>
						<referenz><xsl:value-of select="$nachrichtID"/></referenz>
					</unh>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$required">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="$knoten"/>
						<xsl:with-param name="path" select="$path"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="unhList">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="list" required="yes" as="xs:string"/>
		<xsl:param name="segment" as="xs:integer" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:param name="required" required="no" as="xs:boolean" select="true()"/>
		
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="not(exists(tokenize($list, ',')[. = $knoten]))">
					<unh>
						<code>Z01</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> muss einen der Werte </xsl:text>
							<xsl:value-of select="$list"/>
							<xsl:text> haben, ist aber </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
						<segment><xsl:value-of select="$segment"/></segment>
						<referenz><xsl:value-of select="$nachrichtID"/></referenz>
					</unh>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$required">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="$knoten"/>
						<xsl:with-param name="path" select="$path"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="unhInteger">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="segment" as="xs:integer" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:param name="required" required="no" as="xs:boolean" select="true()"/>
		
		<xsl:choose>
			<xsl:when test="$knoten and string-length($knoten) &gt; 0">
				<xsl:variable name="trimmed" select="normalize-space($knoten)"/>
				<xsl:choose>
					<xsl:when test="string-length($trimmed) &gt; 0">
						<xsl:choose>
							<xsl:when test="$trimmed castable as xs:integer"/>
							<xsl:otherwise>
								<unh>
									<code>Z02</code>
									<freitext>
										<xsl:text>Feld </xsl:text>
										<xsl:value-of select="$path"/>
										<xsl:text> ist nicht numerisch: </xsl:text>
										<xsl:value-of select="$trimmed"/>
									</freitext>
									<segment><xsl:value-of select = "$segment"/></segment>
									<referenz><xsl:value-of select="$nachrichtID"/></referenz>
								</unh>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="$required">
							<xsl:call-template name="unhRequired">
								<xsl:with-param name="knoten" select="$knoten"/>
								<xsl:with-param name="path" select="$path"/>
								<xsl:with-param name="segment" select="$segment"/>
								<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$required">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="$knoten"/>
						<xsl:with-param name="path" select="$path"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="unhRequired">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="segment" as="xs:integer" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="$knoten castable as xs:string">
					<xsl:variable name="asString" select="$knoten" as="xs:string"/>
					<xsl:if test="$asString = ''">
						<unh>
							<code>Z03</code>
							<freitext>
								<xsl:text>Feld </xsl:text>
								<xsl:value-of select="$path"/>
								<xsl:text> ist leer</xsl:text>
							</freitext>
							<segment><xsl:value-of select="$segment"/></segment>
							<referenz><xsl:value-of select="$nachrichtID"/></referenz>
						</unh>
					</xsl:if>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>
						<xsl:text>Feld </xsl:text>
						<xsl:value-of select="$path"/>
						<xsl:text> fehlt</xsl:text>
					</freitext>
					<segment><xsl:value-of select="$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
