<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" 
xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
xmlns:xs="http://www.w3.org/2001/XMLSchema" 
xmlns:fn="http://www.w3.org/2005/xpath-functions"
xmlns:rwe="http://www.rwe.com/gi/ada"
exclude-result-prefixes="xs fn rwe">
	<xsl:output method="xml" version="1.0" encoding="ISO-8859-1" indent="yes"/>

	<xsl:variable name="now" select="current-dateTime()"/>
	<xsl:variable name="nachrichtennummer"
	select="concat('A', format-dateTime($now,
		'[Y02][M01][D01][H01][m01][s01]'), substring(format-dateTime($now, '[f01]'), 1, 1))"/>


	
	<!-- Default-Regel: alles unterdrücken -->
	<xsl:template match="* | @* | text()">
		<xsl:message terminate="yes">
			<xsl:text>Unberücksichtigt: </xsl:text>
			<xsl:for-each select="ancestor::node()">
				<xsl:value-of select="name()"/>
				<xsl:text>/</xsl:text>
			</xsl:for-each>
			<xsl:value-of select="name()"/>
		</xsl:message>
	</xsl:template>

	
	<xsl:template match="/">
		<xsl:copy>
			<xsl:apply-templates select="*" mode="copy"/>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="/*" mode="copy">
		<xsl:copy>
			<xsl:call-template name="IDs"/>
			<xsl:apply-templates select="S_UNB" mode="copy"/>
			<xsl:apply-templates select="M_ORDRSP/G_ORDRSP_SG3/S_NAD[D_3035='MS']" mode="copy"/>
			<xsl:apply-templates select="M_ORDRSP/G_ORDRSP_SG3/S_NAD[D_3035='MR']" mode="copy"/>
			<AperakFehler>
				<xsl:choose>
					<xsl:when test="name() = 'EDIFACTINTERCHANGE'">
						<xsl:apply-templates select="."/>
					</xsl:when>
					<xsl:otherwise>
						<unb>
							<code>Z08</code>
							<freitext>Datei ist leer</freitext>
						</unb>
					</xsl:otherwise>
				</xsl:choose>
			</AperakFehler>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template name="IDs">
		<IDs>
			<now>
				<xsl:value-of select="$now"/>
			</now>
			<nachrichtennummer>
				<xsl:value-of select="$nachrichtennummer"/>
			</nachrichtennummer>
			<nowFormatted>
				<xsl:value-of select="format-dateTime ($now, '[Y02][M01][D01]:[H01][m01]')"/>
			</nowFormatted>
			<nowDTM>
				<xsl:value-of select="format-dateTime($now, '[Y0002][M01][D01][H01][m01]')"/>
			</nowDTM>
		</IDs>
	</xsl:template>
	
	<xsl:template match="* | @* | text()" mode="copy">
		<xsl:copy>
			<xsl:apply-templates select="* | @* | text()" mode="copy"/>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="EDIFACTINTERCHANGE">
		<xsl:choose>
			<xsl:when test="S_UNB">
				<xsl:apply-templates select="S_UNB"/>
			
			
				<!-- Nachrichten prüfen -->
				<xsl:apply-templates select="M_ORDRSP"/>
			</xsl:when>
			<xsl:otherwise>
				<unb>
					<code>Z03</code>
					<freitext>Segment UNB fehlt</freitext>
				</unb>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<!-- *****                                                                            *****  -->
	<!-- *****                     Übertragung (UNB) prüfen                               *****  -->
	<!-- *****                                                                            *****  -->
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_UNB">
		<!-- C_S001/D_0001 muss existieren und 'UNOC' lauten -->
		<xsl:call-template name="unbValue">
			<xsl:with-param name="knoten" select="C_S001/D_0001"/>
			<xsl:with-param name="wert" select="'UNOC'"/>
			<xsl:with-param name="path" select="'UNB/S001/D0001'"/>
		</xsl:call-template>
		
		<!-- C_S001/D_0002 muss existieren und '3' lauten -->
		<xsl:call-template name="unbValue">
			<xsl:with-param name="knoten" select="C_S001/D_0002"/>
			<xsl:with-param name="wert" select="'3'"/>
			<xsl:with-param name="path" select="'UNB/S001/D0002'"/>
		</xsl:call-template>
		
		<!-- C_S002/D_0007 muss existieren und einen gültigen Eintrag aus einer Liste von Werten haben -->
		<xsl:call-template name="unbList">
			<xsl:with-param name="knoten" select="C_S002/D_0007"/>
			<xsl:with-param name="path" select="'UNB/S002/D0007'"/>
			<xsl:with-param name="list" select="'14,500,501,502,ZZZ'"/>
		</xsl:call-template>
		
		<!-- C_S003/D_0007 muss existieren und einen gültigen Eintrag aus einer Liste von Werten haben -->
		<xsl:call-template name="unbList">
			<xsl:with-param name="knoten" select="C_S003/D_0007"/>
			<xsl:with-param name="path" select="'UNB/S003/D0007'"/>
			<xsl:with-param name="list" select="'14,500,501,502,ZZZ'"/>
		</xsl:call-template>
			
		<!-- C_S004/D_0017 muss ein gültiges Datumsformat sein -->
		<xsl:call-template name="unbIsDate">
			<xsl:with-param name="knoten" select="C_S004/D_0017"/>
			<xsl:with-param name="path" select="'UNB/S004/D0017'"/>
		</xsl:call-template>
		
		<!-- C_S004/D_0019 muss ein gültiges Zeitformat sein -->
		<xsl:call-template name="unbIsTime">
			<xsl:with-param name="knoten" select="C_S004/D_0019"/>
			<xsl:with-param name="path" select="'UNB/S004/D0019'"/>
		</xsl:call-template>
		
		<!-- D_0026 muss, sofern vorhanden, aus einer Liste stammen -->
		<xsl:call-template name="unbList">
			<xsl:with-param name="knoten" select="D_0026"/>
			<xsl:with-param name="path" select="'UNB/D0026'"/>
			<xsl:with-param name="required" select="false()"/>
			<xsl:with-param name="list" select="'LG,EM,VL,TL'"/>
		</xsl:call-template>
		
		<!-- D_0032 muss, sofern vorhanden, DISI lauten -->
		<xsl:call-template name="unbValue">
			<xsl:with-param name="knoten" select="D_0032"/>
			<xsl:with-param name="path" select="'UNB/D0032'"/>
			<xsl:with-param name="required" select="false()"/>
			<xsl:with-param name="wert" select="'DISI'"/>
		</xsl:call-template>
	</xsl:template>

	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<!-- *****                                                                            *****  -->
	<!-- *****                     Nachrichten (UNHs) prüfen                              *****  -->
	<!-- *****                                                                            *****  -->
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_ORDRSP">
		<xsl:variable name="nachrichtID" select="S_UNH/D_0062" />
		<xsl:apply-templates select="descendant::node()[substring(name(), 1, 2) = 'S_']">
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
		<xsl:apply-templates select="." mode="Absender">
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
		<xsl:apply-templates select="." mode="Empfaenger">
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           Marktpartner (Absender) prüfen                                   *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_ORDRSP" mode="Absender">
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="G_ORDRSP_SG3/S_NAD[D_3035='MS']">
				<xsl:apply-templates select="G_ORDRSP_SG3/S_NAD[D_3035='MS']" mode="Absender">
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z08</code>
					<freitext>Segment SG3/NAD fuer Absender fehlt</freitext>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
					<segment>0</segment>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="G_ORDRSP_SG3/S_NAD[D_3035='MS']" mode="Absender">
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C082/D_3039"/>
			<xsl:with-param name="path" select="'SG3/NAD/C082/3039 fuer Qualifier MS'"/>
			<xsl:with-param name="segment" select="0"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           Marktpartner (Empfänger) prüfen                                  *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_ORDRSP" mode="Empfaenger">
		<xsl:param name="nachrichtID"/>

		<xsl:choose>
			<xsl:when test="G_ORDRSP_SG3/S_NAD[D_3035='MR']">
				<xsl:apply-templates select="G_ORDRSP_SG3/S_NAD[D_3035='MR']" mode="Empfaenger">
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z08</code>
					<freitext>Segment SG3/NAD fuer Empfaenger fehlt</freitext>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
					<segment>0</segment>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="G_ORDRSP_SG3/S_NAD[D_3035='MR']" mode="Empfaenger">
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C082/D_3039"/>
			<xsl:with-param name="path" select="'SG3/NAD/C082/3039 fuer Qualifier MR'"/>
			<xsl:with-param name="segment" select="0"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>

	
	<!-- **************************************************************************************  -->
	<!-- *****           UNH prüfen                                                       *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_UNH">
		<xsl:param name="nachrichtID"/>
		<xsl:variable name="segment" select="position()"/>
		
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_S009"/>
			<xsl:with-param name="path" select="'UNH/S009'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="D_0062"/>
			<xsl:with-param name="path" select="'UNH/D0062'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

		<xsl:apply-templates select="C_S009">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template match="S_UNH/C_S009">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0065"/>
			<xsl:with-param name="wert" select="'ORDRSP'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0065'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0052"/>
			<xsl:with-param name="wert" select="'D'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0052'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0054"/>
			<xsl:with-param name="wert" select="'10A'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0054'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0051"/>
			<xsl:with-param name="wert" select="'UN'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0051'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0057"/>
			<!-- Ab dem 01.10.2011: -->
			<xsl:with-param name="wert" select="'1.1a'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0057'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
	</xsl:template>

	<!-- **************************************************************************************  -->
	<!-- *****            S_BGM prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_BGM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C002/D_1001"/>
			<xsl:with-param name="path" select="'BGM/C0002/1001'"/>
			<xsl:with-param name="list" select="'7,Z10,Z11,Z12,Z14'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C106/D_1004"/>
			<xsl:with-param name="path" select="'BGM/C106/1004'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>

	

	<!-- **************************************************************************************  -->
	<!-- *****            S_DTM unter ORDRSP-Wurzel prüfen                                *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_ORDRSP/S_DTM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		

		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C507/D_2005"/>
			<xsl:with-param name="path" select="'DTM/C507/2005'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'137,203,Z02'"/>
		</xsl:call-template>

		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C507/D_2380"/>
			<xsl:with-param name="path" select="'DTM/C507/2380'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C507/D_2379"/>
			<xsl:with-param name="path" select="'DTM/C507/2379'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'203,102'"/>
		</xsl:call-template>

		<xsl:choose>
			<xsl:when test="C_C507/D_2005='137'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C507/D_2379"/>
					<xsl:with-param name="wert" select="'203'"/>
					<xsl:with-param name="path" select="'DTM/C507/2379'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="C_C507/D_2005='203' or C_C507/D_2005='Z02'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C507/D_2379"/>
					<xsl:with-param name="wert" select="'102'"/>
					<xsl:with-param name="path" select="'DTM/C507/2379'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
			
		<xsl:apply-templates select="C_C507" mode="validateFormat">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>		
	</xsl:template>
	
	
	
	<!-- **************************************************************************************  -->
	<!-- *****            S_IMD unter ORDRSP-Wurzel prüfen                                *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_ORDRSP/S_IMD">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		

		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C272/D_7081"/>
			<xsl:with-param name="path" select="'IMD/C272/7081'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'Z01,Z02,Z07,Z08,Z10,Z11,Z12,Z13,Z14'"/>
		</xsl:call-template>

		<xsl:choose>
			<xsl:when test="C_C272/D_7081='Z14'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C273/D_7009"/>			
					<xsl:with-param name="list" select="'Z06,Z07'"/>
					<xsl:with-param name="path" select="'SG29/IMD/C273/7009'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		
	</xsl:template>
	
	
	
	<!-- **************************************************************************************  -->
	<!-- *****            SG1/RFF prüfen								                           *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_ORDRSP_SG1/S_RFF">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		

		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="C_C506/D_1153"/>
			<xsl:with-param name="path" select="'RFF/C506/1153'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="wert" select="'ON'"/>
		</xsl:call-template>

		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C506/D_1154"/>
			<xsl:with-param name="path" select="'RFF/C506/1154'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
	</xsl:template>
	
	
	<!-- **************************************************************************************  -->
	<!-- *****            S_DTM unter SG1 prüfen                                *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_ORDRSP_SG1/S_DTM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="C_C507/D_2005"/>
			<xsl:with-param name="path" select="'SG1/DTM/C507/2005'"/>
			<xsl:with-param name="wert" select="'171'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C507/D_2380"/>
			<xsl:with-param name="path" select="'SG1/DTM/C507/2380'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C507/D_2379"/>
			<xsl:with-param name="path" select="'SG1/DTM/C507/2379'"/>
			<xsl:with-param name="list" select="'203'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:apply-templates select="C_C507" mode="validateFormat">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>	
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****            SG2/AJT prüfen								                           *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_ORDRSP_SG2/S_AJT">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		

		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_4465"/>
			<xsl:with-param name="path" select="'SG2/AJT/4465'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'5,Z13,Z14,Z15,Z16,Z17,Z18,Z19,Z21,Z22,Z23,Z24,Z25,Z26,Z27,Z28,Z29,Z30,Z31,Z32,ZD7,ZD8'"/>
		</xsl:call-template>

	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_NAD unter der zweite Segmentgruppe prüfen                       *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_ORDRSP_SG3/S_NAD">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_3035"/>
			<xsl:with-param name="path" select="'SG3/NAD/3035'"/>
			<xsl:with-param name="list" select="'MS,MR,DP,Z03'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:choose>
			<xsl:when test="D_3035='MR' or D_3035='MS'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C082/D_3055_1"/>
					<xsl:with-param name="path" select="'SG3/NAD/C082/3055'"/>
					<xsl:with-param name="list" select="'9,293,305,321,332'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
				<xsl:call-template name="unhRequired">
					<xsl:with-param name="knoten" select="C_C082/D_3039"/>
					<xsl:with-param name="path" select="'SG3/NAD/C082/3039'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>			
			</xsl:when>
			<xsl:when test="D_3035='Z03'">
				<xsl:call-template name="unhRequired">
					<xsl:with-param name="knoten" select="D_3164"/>
					<xsl:with-param name="path" select="'SG3/NAD/3164'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>			
				<xsl:call-template name="unhRequired">
					<xsl:with-param name="knoten" select="D_3251"/>
					<xsl:with-param name="path" select="'SG3/NAD/3251'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>	
				<xsl:call-template name="unhRequired">
					<xsl:with-param name="knoten" select="D_3207"/>
					<xsl:with-param name="path" select="'SG3/NAD/3207'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>	
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	
	
		
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_CTA prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_CTA">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>

		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_3139"/>
			<xsl:with-param name="wert" select="'IC'"/>
			<xsl:with-param name="path" select="'SG3/SG6/CTA/3139'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C056/D_3412"/>
			<xsl:with-param name="path" select="'SG3/SG6/CTA/C056/3412'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_COM prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_COM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C076/D_3155"/>
			<xsl:with-param name="path" select="'SG3/SG6/COM/C076/3511'"/>
			<xsl:with-param name="list" select="'TE,EM,AJ,AL,FX'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
	</xsl:template>
	
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_LOC prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_ORDRSP_SG3/S_LOC">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_3227"/>
			<xsl:with-param name="list" select="'107,172'"/>
			<xsl:with-param name="path" select="'SG3/LOC/3227'"/>
			<xsl:with-param name="required" select="false()"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C517/D_3225"/>
			<xsl:with-param name="path" select="'SG3/LOC/C517/3225'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:if test="D_3227='107'">
				<xsl:call-template name="unhValue">
				<xsl:with-param name="knoten" select="C_C517/D_3055"/>
					<xsl:with-param name="wert" select="'Z01'"/>
					<xsl:with-param name="path" select="'SG3/C517/3055'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
		</xsl:if>
	</xsl:template>
			
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_CUX prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_ORDRSP_SG8/S_CUX">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="C_C504/D_6347"/>
			<xsl:with-param name="wert" select="'2'"/>
			<xsl:with-param name="path" select="'SG8/CUX/C504/6347'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C504/D_6345"/>
			<xsl:with-param name="path" select="'SG8/CUX/C504/6345'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="C_C504/D_6343"/>
			<xsl:with-param name="wert" select="'9'"/>
			<xsl:with-param name="path" select="'SG8/CUX/C504/6343'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
	</xsl:template>
	
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_LIN prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_ORDRSP_SG27/S_LIN">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
	
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="D_1082"/>
			<xsl:with-param name="path" select="'SG27/LIN/1082'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C212/D_7140"/>
			<xsl:with-param name="path" select="'SG27/LIN/C212/7140'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="C_C212/D_7143"/>
			<xsl:with-param name="wert" select="'Z01'"/>
			<xsl:with-param name="path" select="'SG27/LIN/C212/7143'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
	</xsl:template>
	
		
	<!-- **************************************************************************************  -->
	<!-- *****           S_QTY prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_ORDRSP_SG27/S_QTY">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
	
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="C_C186/D_6063"/>			
			<xsl:with-param name="wert" select="'145'"/>
			<xsl:with-param name="path" select="'SG29/QTY/C186/6063'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C186/D_6060"/>
			<xsl:with-param name="path" select="'SG29/QTY/C186/6060'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
			
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="C_C186/D_6411"/>			
			<xsl:with-param name="wert" select="'PCS'"/>
			<xsl:with-param name="path" select="'SG29/QTY/C186/6411'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
	</xsl:template>
	
		
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_MOA prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_ORDRSP_SG27/S_MOA">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
			
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="C_C516/D_5025"/>			
			<xsl:with-param name="wert" select="'203'"/>
			<xsl:with-param name="path" select="'SG27/MOA/C516/5025'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
				
	</xsl:template>
	
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_FTX prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_ORDRSP_SG27/S_FTX">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
			
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_4451"/>			
			<xsl:with-param name="wert" select="'ACB'"/>
			<xsl:with-param name="path" select="'SG27/FTX/4451'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
				
	</xsl:template>
	
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_PRI prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_ORDRSP_SG27/G_ORDRSP_SG31/S_PRI">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
			
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="C_C509/D_5125"/>			
			<xsl:with-param name="wert" select="'CAL'"/>
			<xsl:with-param name="path" select="'SG27/SG31/PRI/C509/5125'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
							
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C509/D_5118"/>			
			<xsl:with-param name="path" select="'SG27/SG31/PRI/C509/5118'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
	</xsl:template>
		

	<!-- **************************************************************************************  -->
	<!-- *****           S_RFF prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_ORDRSP_SG27/G_ORDRSP_SG32/S_RFF">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
			
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C506/D_1153"/>			
			<xsl:with-param name="list" select="'MG,Z06'"/>
			<xsl:with-param name="path" select="'SG27/SG32/RFF/C506/1153'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
							
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C506/D_1154"/>			
			<xsl:with-param name="path" select="'SG27/SG32/RFF/C506/1154'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
	</xsl:template>
		
			
	<!-- **************************************************************************************  -->
	<!-- *****           S_UNS prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_UNS">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
	
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0081"/>
			<xsl:with-param name="wert" select="'S'"/>
			<xsl:with-param name="path" select="'UNS/0081'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	
	
	<!-- **************************************************************************************  -->
	<!-- *****           S_MOA prüfen                                                     *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_ORDRSP/S_MOA">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
	
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="C_C516/D_5025"/>
			<xsl:with-param name="wert" select="'24'"/>
			<xsl:with-param name="path" select="'MOA/C516/5025'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C516/D_5004"/>
			<xsl:with-param name="path" select="'MOA/C516/5004'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
				
	</xsl:template>
	
	<!-- **************************************************************************************  -->
	<!-- *****           diese Segmente bleiben ungeprüft                                 *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_UNT"/>

	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<!-- *****                                                                            *****  -->
	<!-- *****                     Transformations-Funktionen                             *****  -->
	<!-- *****                                                                            *****  -->
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<xsl:template name="unbValue">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="wert" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="required" required="no" as="xs:boolean" select="true()"/>
		
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="$knoten != $wert">
					<unb>
						<code>Z01</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> muss </xsl:text>
							<xsl:value-of select="$wert"/>
							<xsl:text> lauten, ist aber </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
					</unb>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$required">
					<xsl:call-template name="unbRequired">
						<xsl:with-param name="knoten" select="$knoten"/>
						<xsl:with-param name="path" select="$path"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="unbList">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="list" required="yes" as="xs:string"/>
		<xsl:param name="required" required="no" as="xs:boolean" select="true()"/>
		
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="not(exists(tokenize($list, ',')[. = $knoten]))">
					<unb>
						<code>Z01</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> muss </xsl:text>
							<xsl:value-of select="$list"/>
							<xsl:text> lauten, ist aber </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
					</unb>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$required">
					<xsl:call-template name="unbRequired">
						<xsl:with-param name="knoten" select="$knoten"/>
						<xsl:with-param name="path" select="$path"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="unbRequired">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:if test="not($knoten)">
			<unb>
				<code>Z03</code>
				<freitext>
					<xsl:text>Feld </xsl:text>
					<xsl:value-of select="$path"/>
					<xsl:text> fehlt</xsl:text>
				</freitext>
			</unb>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="unbIsDate">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:variable name="formatted">
					<xsl:text>20</xsl:text>
					<xsl:value-of select="substring($knoten, 1, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring($knoten, 3, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring($knoten, 5, 2)"/>
				</xsl:variable>
				<xsl:if test="not($formatted castable as xs:date)">
					<unb>
						<code>Z02</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> entspricht nicht dem Datumsformat YYMMDD: </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
					</unb>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="unbRequired">
					<xsl:with-param name="knoten" select="$knoten"/>
					<xsl:with-param name="path" select="$path"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="unbIsTime">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:variable name="formatted">
					<xsl:value-of select="substring($knoten, 1, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring($knoten, 3, 2)"/>
					<xsl:text>:00</xsl:text>
				</xsl:variable>
				<xsl:if test="not($formatted castable as xs:time)">
					<unb>
						<code>Z02</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> entspricht nicht dem Zeitformat HHMM: </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
					</unb>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="unbRequired">
					<xsl:with-param name="knoten" select="$knoten"/>
					<xsl:with-param name="path" select="$path"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="unhValue">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="wert" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="required" required="no" as="xs:boolean" select="true()"/>
		<xsl:param name="segment" as="xs:integer" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="$knoten != $wert">
					<unh>
						<code>Z01</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> muss </xsl:text>
							<xsl:value-of select="$wert"/>
							<xsl:text> lauten, ist aber </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
						<segment><xsl:value-of select="$segment"/></segment>
						<referenz><xsl:value-of select="$nachrichtID"/></referenz>
					</unh>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$required">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="$knoten"/>
						<xsl:with-param name="path" select="$path"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="unhList">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="list" required="yes" as="xs:string"/>
		<xsl:param name="segment" as="xs:integer" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:param name="required" required="no" as="xs:boolean" select="true()"/>
		
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="not(exists(tokenize($list, ',')[. = $knoten]))">
					<unh>
						<code>Z01</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> muss einen der Werte </xsl:text>
							<xsl:value-of select="$list"/>
							<xsl:text> haben, ist aber </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
						<segment><xsl:value-of select="$segment"/></segment>
						<referenz><xsl:value-of select="$nachrichtID"/></referenz>
					</unh>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$required">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="$knoten"/>
						<xsl:with-param name="path" select="$path"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="unhRequired">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="segment" as="xs:integer" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="$knoten castable as xs:string">
					<xsl:variable name="asString" select="$knoten" as="xs:string"/>
					<xsl:if test="$asString = ''">
						<unh>
							<code>Z03</code>
							<freitext>
								<xsl:text>Feld </xsl:text>
								<xsl:value-of select="$path"/>
								<xsl:text> ist leer</xsl:text>
							</freitext>
							<segment><xsl:value-of select="$segment"/></segment>
							<referenz><xsl:value-of select="$nachrichtID"/></referenz>
						</unh>
					</xsl:if>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>
						<xsl:text>Feld </xsl:text>
						<xsl:value-of select="$path"/>
						<xsl:text> fehlt</xsl:text>
					</freitext>
					<segment><xsl:value-of select="$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<!-- *****                                                                            *****  -->
	<!-- *****                     Validierung von Datumsformaten                         *****  -->
	<!-- *****                                                                            *****  -->
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_DTM/C_C507[D_2379='303']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 14">
				<xsl:variable name="zeitzone1" select="substring(D_2380, 13)"/>
				<xsl:variable name="zeitzone">
					<xsl:choose>
						<xsl:when test="substring($zeitzone1, 1, 1) = '?'">
							<xsl:value-of select="substring($zeitzone1, 2)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$zeitzone1"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 7, 2)"/>
					<xsl:text>T</xsl:text>
					<xsl:value-of select="substring(D_2380, 9, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring(D_2380, 11, 2)"/>
					<xsl:text>:00.000</xsl:text>
					<xsl:value-of select="$zeitzone"/>
					<xsl:text>:00</xsl:text>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:dateTime"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>
								<xsl:text>Feld DTM/C507/2380 entspricht nicht dem Datumsformat</xsl:text>
								<xsl:text> 303 - CCYYMMDDHHMMZZZ: </xsl:text>
								<xsl:value-of select="D_2380"/>
							</freitext>
							<segment><xsl:value-of select = "$segment"/></segment>
							<referenz><xsl:value-of select="$nachrichtID"/></referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 203 - CCYYMMDDHHMMZZZ</freitext>
					<segment><xsl:value-of select = "$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
		
	<xsl:template match="S_DTM/C_C507[D_2379='203']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 11">
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 7, 2)"/>
					<xsl:text>T</xsl:text>
					<xsl:value-of select="substring(D_2380, 9, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring(D_2380, 11, 2)"/>
					<xsl:text>:00.000</xsl:text>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:dateTime"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 203 - CCYYMMDDHHMM</freitext>
							<segment><xsl:value-of select = "$segment"/></segment>
							<referenz><xsl:value-of select="$nachrichtID"/></referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 203 - CCYYMMDDHHMM</freitext>
					<segment><xsl:value-of select = "$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
		
	<xsl:template match="S_DTM/C_C507[D_2379='204']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 13">
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 7, 2)"/>
					<xsl:text>T</xsl:text>
					<xsl:value-of select="substring(D_2380, 9, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring(D_2380, 11, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring(D_2380, 13, 2)"/>
					<xsl:text>.000</xsl:text>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:dateTime"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 204 - CCYYMMDDHHMMSS</freitext>
							<segment><xsl:value-of select = "$segment"/></segment>
							<referenz><xsl:value-of select="$nachrichtID"/></referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 204 - CCYYMMDDHHMMSS</freitext>
					<segment><xsl:value-of select = "$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
		
	<xsl:template match="S_DTM/C_C507[D_2379='102']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 7">
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 7, 2)"/>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:date"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 102 - CCYYMMDD</freitext>
							<segment><xsl:value-of select = "$segment"/></segment>
							<referenz><xsl:value-of select="$nachrichtID"/></referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 102 - CCYYMMDD</freitext>
					<segment><xsl:value-of select = "$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
		
	<xsl:template match="S_DTM/C_C507[D_2379='806']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 0">
				<xsl:choose>
					<xsl:when test="D_2380 castable as xs:integer">
						<xsl:variable name="asInt" as="xs:integer" select="D_2380"/>
						<xsl:if test="$asInt &lt; 0 or $asInt &gt; 59">
							<unh>
								<code>Z02</code>
								<freitext>
									<xsl:text>Feld DTM/C507/2380 ist keine Minute: </xsl:text>
									<xsl:value-of select="$asInt"/>
								</freitext>
								<segment><xsl:value-of select = "$segment"/></segment>
								<referenz><xsl:value-of select="$nachrichtID"/></referenz>
							</unh>
						</xsl:if>
					</xsl:when>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 806 - Minuten</freitext>
							<segment><xsl:value-of select = "$segment"/></segment>
							<referenz><xsl:value-of select="$nachrichtID"/></referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 806 - Minuten</freitext>
					<segment><xsl:value-of select = "$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
		
	<xsl:template match="S_DTM/C_C507[D_2379='610']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 5">
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-01</xsl:text>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:date"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 610 - CCYYMM</freitext>
							<segment><xsl:value-of select = "$segment"/></segment>
							<referenz><xsl:value-of select="$nachrichtID"/></referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 610 - CCYYMM</freitext>
					<segment><xsl:value-of select = "$segment"/></segment>
					<referenz><xsl:value-of select="$nachrichtID"/></referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="S_DTM/C_C507" mode="validateFormat" priority="5">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:message terminate="yes">
			<xsl:text>Unberücksichtigtes Format in "validateFormat": </xsl:text>
			<xsl:value-of select="D_2379"/>
			<xsl:text> in Referenz </xsl:text>
			<xsl:value-of select="$nachrichtID"/>
			<xsl:text> Segment </xsl:text>
			<xsl:value-of select="$segment"/>
		</xsl:message>
	</xsl:template>
</xsl:stylesheet>
