<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" 
xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
xmlns:xs="http://www.w3.org/2001/XMLSchema" 
xmlns:fn="http://www.w3.org/2005/xpath-functions"
xmlns:rwe="http://www.rwe.com/gi/ada"
exclude-result-prefixes="xs fn rwe">
	<xsl:output method="xml" version="1.0" encoding="ISO-8859-1" indent="yes"/>

	
	<xsl:template match="EDIFACTINTERCHANGE">
		
		<xsl:variable name="now" select="current-dateTime()"/>
		<xsl:variable name="nachrichtennummer" select="concat('A', format-dateTime($now,	'[Y02][M01][D01][H01][m01][s01]'), substring(format-dateTime($now, '[f01]'), 1, 1))"/>
		
		<root>
	
		<infos>
			<absender><xsl:value-of select="S_UNB/C_S003/D_0010"/></absender>
			<empfaenger><xsl:value-of select="S_UNB/C_S002/D_0004"/></empfaenger>
			<nachrichtennummer><xsl:value-of select="$nachrichtennummer"/></nachrichtennummer>
			<referenznummer><xsl:value-of select="S_UNB/D_0020"/></referenznummer>
			<nowDTM><xsl:value-of select="format-dateTime($now, '[Y0002][M01][D01][H01][m01]')"/></nowDTM>
		</infos>

		<fehler>
		<xsl:variable name="counterUNA" select="count(S_UNA)"/>
		<xsl:variable name="counterUNB" select="count(S_UNB)"/>
		<xsl:variable name="counterUNZ" select="count(S_UNZ)"/>

		<!-- UNA prüfen -->
		<xsl:if test="counterUNA &gt; 1">
			<xsl:choose>
				<xsl:when test="count(S_UNA/child::*) &lt; 6">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="13"/>
						<xsl:with-param name="segment" select="'UNA'"/>							
						<xsl:with-param name="gruppenposition" select="count(S_UNA/child::*)+1"/>
					</xsl:call-template>	
				</xsl:when>
				<xsl:when test="count(S_UNA/child::*) &gt; 6">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="16"/>
						<xsl:with-param name="segment" select="'UNA'"/>
						<xsl:with-param name="gruppenposition" select="8"/>
					</xsl:call-template>	
				</xsl:when>				
			</xsl:choose>
					
			<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNA/D_UNA1"/>
					<xsl:with-param name="segment" select="'UNA'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
			</xsl:call-template>	
		    <xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNA/D_UNA2"/>
					<xsl:with-param name="segment" select="'UNA'"/>
					<xsl:with-param name="gruppenposition" select="3"/>
			</xsl:call-template>	
		    <xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNA/D_UNA3"/>
					<xsl:with-param name="segment" select="'UNA'"/>
					<xsl:with-param name="gruppenposition" select="4"/>
			</xsl:call-template>	
		    <xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNA/D_UNA4"/>
					<xsl:with-param name="segment" select="'UNA'"/>
					<xsl:with-param name="gruppenposition" select="5"/>
			</xsl:call-template>	
		    <xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNA/D_UNA5"/>
					<xsl:with-param name="segment" select="'UNA'"/>
					<xsl:with-param name="gruppenposition" select="6"/>
			</xsl:call-template>	
		    <xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNA/D_UNA6"/>
					<xsl:with-param name="segment" select="'UNA'"/>
					<xsl:with-param name="gruppenposition" select="7"/>
			</xsl:call-template>		
		</xsl:if>		
				
		<!-- UNB prüfen -->
		<xsl:choose>
			<xsl:when test="$counterUNB = 0">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="code" select="13"/>
					<xsl:with-param name="segment" select="'UNB'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$counterUNB = 1">
				<xsl:if test="S_UNB/C_S001/D_0001 != 'UNOC'">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="2"/>
						<xsl:with-param name="segment" select="'UNB'"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="1"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="S_UNB/C_S001/D_0002 != '3'">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="2"/>
						<xsl:with-param name="segment" select="'UNB'"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="2"/>
					</xsl:call-template>
				</xsl:if>				
		<!--		<xsl:if test="S_UNB/C_S003/D_0010 != $empfaenger">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="7"/>
						<xsl:with-param name="segment" select="'UNB'"/>
						<xsl:with-param name="gruppenposition" select="count(S_UNB/C_S003/preceding-sibling::*)+1"/>
						<xsl:with-param name="elementposition" select="count(S_UNB/C_S003/D_0010/preceding-sibling::*)+1"/>
					</xsl:call-template>
				</xsl:if>
	-->
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/C_S001/D_0001"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="1"/>
				</xsl:call-template>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/C_S001/D_0002"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="2"/>
				</xsl:call-template>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/C_S002/D_0004"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="gruppenposition" select="3"/>
					<xsl:with-param name="elementposition" select="1"/>
				</xsl:call-template>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/C_S002/D_0007"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="wertebereich" select="'14,500,501,502,ZZZ'"/>
					<xsl:with-param name="gruppenposition" select="3"/>
					<xsl:with-param name="elementposition" select="2"/>
				</xsl:call-template>	
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/C_S003/D_0010"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="gruppenposition" select="4"/>
					<xsl:with-param name="elementposition" select="1"/>
				</xsl:call-template>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/C_S003/D_0007"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="wertebereich" select="'14,500,501,502,ZZZ'"/>
					<xsl:with-param name="gruppenposition" select="4"/>
					<xsl:with-param name="elementposition" select="2"/>
				</xsl:call-template>			
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/C_S004/D_0017"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="gruppenposition" select="5"/>
					<xsl:with-param name="elementposition" select="1"/>
				</xsl:call-template>		
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/C_S004/D_0019"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="gruppenposition" select="5"/>
					<xsl:with-param name="elementposition" select="2"/>
				</xsl:call-template>		
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/D_0020"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="gruppenposition" select="6"/>
				</xsl:call-template>																
			</xsl:when>			
		</xsl:choose>
	
	
		<!-- UNZ prüfen -->
		<xsl:choose>
			<xsl:when test="$counterUNZ = 0">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="code" select="13"/>
					<xsl:with-param name="segment" select="'UNZ'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$counterUNZ = 1">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNZ/D_0036"/>
					<xsl:with-param name="segment" select="'UNZ'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
				</xsl:call-template>		
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNZ/D_0020"/>
					<xsl:with-param name="segment" select="'UNZ'"/>
					<xsl:with-param name="gruppenposition" select="3"/>
				</xsl:call-template>						
				<xsl:variable name="anzahlNachrichten" select="count(M_UTILMD/S_UNH)"/>
				<xsl:if test="$anzahlNachrichten != S_UNZ/D_0036">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="29"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="segment" select="'UNZ'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>			
		</xsl:choose>

		<!-- Prüfreferenzen UNB und UNZ vergleichen -->
		<xsl:if test="S_UNB/D_0020 != S_UNZ/D_0020">
			<xsl:call-template name="Fehler">
				<xsl:with-param name="code" select="28"/>
				<xsl:with-param name="gruppenposition" select="3"/>
				<xsl:with-param name="segment" select="'UNZ'"/>
			</xsl:call-template>
		</xsl:if>
		
		<!-- Prüfen ob UNHs enthalten sind -->
		<xsl:if test="count(M_UTILMD/S_UNH) = 0">
			<xsl:call-template name="Fehler">
				<xsl:with-param name="code" select="32"/>
				<xsl:with-param name="segment" select="'UNB'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- Prüfen ob UNHs und UNTs vorhanden sind -->
		<xsl:variable name="counterUNH" select="count(M_UTILMD/S_UNH)"/>
		<xsl:variable name="counterUNT" select="count(M_UTILMD/S_UNT)"/>
		
		<xsl:if test="$counterUNH = 0">
			<xsl:call-template name="Fehler">
				<xsl:with-param name="code" select="13"/>
				<xsl:with-param name="segment" select="'UNH'"/>
			</xsl:call-template>
		</xsl:if>
				
		<xsl:if test="$counterUNT = 0">
			<xsl:call-template name="Fehler">
				<xsl:with-param name="code" select="13"/>
				<xsl:with-param name="segment" select="'UNH'"/>
			</xsl:call-template>
		</xsl:if>
		
		
		<xsl:for-each select="M_UTILMD">
			<nachricht>
			<xsl:attribute name="idUNH" select="S_UNH/D_0062"/>
			<xsl:attribute name="nachrichtenkennung" select="S_UNH/C_S009/D_0065"/>
			<xsl:attribute name="freigabenummer" select="S_UNH/C_S009/D_0054"/>
			<xsl:attribute name="versionsnummer" select="S_UNH/C_S009/D_0052"/>
			<!-- UNH prüfen -->
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/D_0062"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="max" select="14"/>
				<xsl:with-param name="gruppenposition" select="2"/>
			</xsl:call-template>	
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/C_S009/D_0065"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="max" select="6"/>
				<xsl:with-param name="wertebereich" select="'UTILMD'"/>
				<xsl:with-param name="gruppenposition" select="3"/>
				<xsl:with-param name="elementposition" select="1"/>
			</xsl:call-template>				
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/C_S009/D_0052"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="max" select="3"/>
				<xsl:with-param name="wertebereich" select="'D'"/>
				<xsl:with-param name="gruppenposition" select="3"/>
				<xsl:with-param name="elementposition" select="2"/>
			</xsl:call-template>				
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/C_S009/D_0054"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="max" select="3"/>
				<xsl:with-param name="wertebereich" select="'11A'"/>
				<xsl:with-param name="gruppenposition" select="3"/>
				<xsl:with-param name="elementposition" select="3"/>
			</xsl:call-template>				
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/C_S009/D_0051"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="max" select="2"/>
				<xsl:with-param name="wertebereich" select="'UN'"/>
				<xsl:with-param name="gruppenposition" select="3"/>
				<xsl:with-param name="elementposition" select="4"/>
			</xsl:call-template>				
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/C_S009/D_0057"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="max" select="6"/>
				<xsl:with-param name="wertebereich" select="'5.1g'"/>
				<xsl:with-param name="gruppenposition" select="3"/>
				<xsl:with-param name="elementposition" select="5"/>
			</xsl:call-template>		
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/D_0068"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="max" select="35"/>
				<xsl:with-param name="gruppenposition" select="4"/>
				<xsl:with-param name="pflichtfeld" select="false()"/>
			</xsl:call-template>		
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/C_S010/D_0070"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="max" select="2"/>
				<xsl:with-param name="gruppenposition" select="5"/>
				<xsl:with-param name="elementposition" select="1"/>
				<xsl:with-param name="pflichtfeld" select="false()"/>
				<xsl:with-param name="zeichenart" select="'n'"/>		
			</xsl:call-template>																									
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/C_S010/D_0073"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="min" select="1"/>
				<xsl:with-param name="max" select="1"/>
				<xsl:with-param name="wertebereich" select="'C,F'"/>
				<xsl:with-param name="gruppenposition" select="5"/>
				<xsl:with-param name="elementposition" select="2"/>
				<xsl:with-param name="pflichtfeld" select="false()"/>
			</xsl:call-template>	
			
						
			<!-- UNT prüfen -->		
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNT/D_0074"/>
				<xsl:with-param name="max" select="6"/>
				<xsl:with-param name="segment" select="'UNT'"/>
				<xsl:with-param name="gruppenposition" select="2"/>
			</xsl:call-template>		
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNT/D_0062"/>
				<xsl:with-param name="max" select="14"/>
				<xsl:with-param name="segment" select="'UNT'"/>
				<xsl:with-param name="gruppenposition" select="3"/>
			</xsl:call-template>						
			
			<!-- Prüfreferenzen UNH und UNT vergleichen -->
			<xsl:if test="S_UNH/D_0062 != S_UNT/D_0062">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="code" select="28"/>
					<xsl:with-param name="gruppenposition" select="3"/>
					<xsl:with-param name="segment" select="'UNT'"/>
				</xsl:call-template>
			</xsl:if>
		
		<xsl:message>Anzahl Nachricht:<xsl:value-of select="count(descendant::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA' and name() != 'S_UNZ'])"/> </xsl:message>
		<xsl:message>Anzahl UNT:<xsl:value-of select="S_UNT/D_0074"/> </xsl:message>
			<!-- Anzahl Segmente prüfen -->
			<xsl:if test="count(descendant::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA' and name() != 'S_UNZ']) != S_UNT/D_0074">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="code" select="29"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="segment" select="'UNT'"/>
				</xsl:call-template>
			</xsl:if>

			
			<!-- BGM prüfen -->
			<xsl:variable name="counterBGM" select="count(S_BGM)"/>
			
			<xsl:choose>
				<xsl:when test="$counterBGM = 0">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="13"/>
						<xsl:with-param name="segmentposition" select="$counterUNH"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$counterBGM &gt; 1">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="35"/>
						<xsl:with-param name="segmentposition" select="$counterUNH+2"/>
					</xsl:call-template>
				</xsl:when>								
				<xsl:otherwise>
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="S_BGM/C_C002/D_1001"/>
						<xsl:with-param name="min" select="1"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'E01,E02,E03,E06,Z14,E35,E44,Z02,E40,Z05,Z07,Z13,Z17,Z18,Z22,Z26,Z35'"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="S_BGM"/>
					</xsl:call-template>		
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="S_BGM/C_C106/D_1004"/>
						<xsl:with-param name="min" select="1"/>
						<xsl:with-param name="max" select="70"/>
						<xsl:with-param name="gruppenposition" select="3"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="S_BGM"/>
					</xsl:call-template>							
				</xsl:otherwise>
			</xsl:choose>
			
			<!-- DTM prüfen -->
			<xsl:variable name="counterDTM" select="count(S_DTM)"/>
		
			<!-- DTM 137 prüfen -->
			<xsl:variable name="counterDTM137" select="count(S_DTM/C_C507[D_2005='137'])"/>
	
			<xsl:choose>
				<xsl:when test="$counterDTM = 0">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="segmentposition" select="$counterUNH+$counterBGM"/>
						<xsl:with-param name="code" select="13"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$counterDTM137 = 0">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="segmentposition" select="$counterUNH+$counterBGM"/>
						<xsl:with-param name="code" select="13"/>
					</xsl:call-template>
				</xsl:when>				
				<xsl:otherwise>
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="S_DTM[1]/C_C507/D_2005"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'137'"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="S_DTM[1]"/>
					</xsl:call-template>		
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="S_DTM[1]/C_C507/D_2380"/>
						<xsl:with-param name="max" select="35"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="2"/>
						<xsl:with-param name="segmentknoten" select="S_DTM[1]"/>
					</xsl:call-template>	
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="S_DTM[1]/C_C507/D_2379"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'203'"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="3"/>
						<xsl:with-param name="segmentknoten" select="S_DTM[1]"/>
					</xsl:call-template>				
					<xsl:for-each select="S_DTM">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="C_C507/D_2005"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="wertebereich" select="'137,735,157'"/>
							<xsl:with-param name="gruppenposition" select="2"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="."/>
						</xsl:call-template>		
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="C_C507/D_2380"/>
							<xsl:with-param name="max" select="35"/>
							<xsl:with-param name="gruppenposition" select="2"/>
							<xsl:with-param name="elementposition" select="2"/>
							<xsl:with-param name="segmentknoten" select="."/>
						</xsl:call-template>	
						<xsl:choose>
							<xsl:when test="C_C507/D_2005='735'">
								<xsl:call-template name="PruefeFeld">
									<xsl:with-param name="knoten" select="C_C507/D_2379"/>
									<xsl:with-param name="max" select="3"/>
									<xsl:with-param name="wertebereich" select="'406'"/>
									<xsl:with-param name="gruppenposition" select="2"/>
									<xsl:with-param name="elementposition" select="3"/>
									<xsl:with-param name="segmentknoten" select="."/>
								</xsl:call-template>		
							</xsl:when>
							<xsl:when test="C_C507/D_2005='157'">
								<xsl:call-template name="PruefeFeld">
									<xsl:with-param name="knoten" select="C_C507/D_2379"/>
									<xsl:with-param name="max" select="3"/>
									<xsl:with-param name="wertebereich" select="'610'"/>
									<xsl:with-param name="gruppenposition" select="2"/>
									<xsl:with-param name="elementposition" select="3"/>
									<xsl:with-param name="segmentknoten" select="."/>
								</xsl:call-template>		
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>								
				</xsl:otherwise>
			</xsl:choose>
			
			<!-- RFF prüfen -->
			<xsl:variable name="counterRFF" select="count(G_UTILMD_SG1/S_RFF)"/>

			<xsl:for-each select="G_UTILMD_SG1/S_RFF">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C506/D_1153"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'AAV'"/>		
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C506/D_1154"/>
					<xsl:with-param name="max" select="70"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>
			</xsl:for-each>
	
			<!-- NAD prüfen -->
			<xsl:variable name="counterNAD" select="count(G_UTILMD_SG2/S_NAD)"/>
			
			<xsl:if test="not(G_UTILMD_SG2/S_NAD[D_3035='MS'])">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterUNH+$counterBGM+$counterDTM+$counterRFF"/>
					<xsl:with-param name="code" select="13"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="not(G_UTILMD_SG2/S_NAD[D_3035='MR'])">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterUNH+$counterBGM+$counterDTM+$counterRFF+$counterNAD"/>
					<xsl:with-param name="code" select="13"/>
				</xsl:call-template>
			</xsl:if>		
				
			<xsl:for-each select="G_UTILMD_SG2/S_NAD">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="D_3035"/>
					<xsl:with-param name="min" select="1"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'MS,MR'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>	
				
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C082/D_3039"/>
					<xsl:with-param name="min" select="1"/>
					<xsl:with-param name="max" select="35"/>
					<xsl:with-param name="gruppenposition" select="3"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>					
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C082/D_3055_1"/>
					<xsl:with-param name="min" select="1"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'9,293,305,321,332'"/>
					<xsl:with-param name="gruppenposition" select="3"/>
					<xsl:with-param name="elementposition" select="3"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>	
				
			</xsl:for-each>	

			<xsl:if test="G_UTILMD_SG2[2]/G_UTILMD_SG3">
				<xsl:choose>
					<xsl:when test="not(G_UTILMD_SG2[2]/G_UTILMD_SG3/S_CTA)">
						<xsl:call-template name="Fehler">
							<xsl:with-param name="segmentposition" select="5"/>
							<xsl:with-param name="code" select="13"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="G_UTILMD_SG2[2]/G_UTILMD_SG3/S_CTA/D_3139"/>
							<xsl:with-param name="min" select="1"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="wertebereich" select="'IC'"/>		
							<xsl:with-param name="gruppenposition" select="2"/>
							<xsl:with-param name="segmentknoten" select="G_UTILMD_SG2[2]/G_UTILMD_SG3/S_CTA"/>
						</xsl:call-template>	
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="G_UTILMD_SG2[2]/G_UTILMD_SG3/S_CTA/C_C056/D_3412"/>
							<xsl:with-param name="min" select="1"/>
							<xsl:with-param name="max" select="256"/>
							<xsl:with-param name="gruppenposition" select="3"/>
							<xsl:with-param name="elementposition" select="2"/>
							<xsl:with-param name="segmentknoten" select="G_UTILMD_SG2[2]/G_UTILMD_SG3/S_CTA"/>
						</xsl:call-template>									
					</xsl:otherwise>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="not(G_UTILMD_SG2[2]/G_UTILMD_SG3/S_COM)">
						<xsl:call-template name="Fehler">
							<xsl:with-param name="segmentposition" select="6"/>
							<xsl:with-param name="code" select="13"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="G_UTILMD_SG2[2]/G_UTILMD_SG3/S_COM">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C076/D_3148"/>
								<xsl:with-param name="min" select="1"/>
								<xsl:with-param name="max" select="512"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>	
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C076/D_3155"/>
								<xsl:with-param name="min" select="1"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'EM,FX,TE,AJ,AL'"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>		
						</xsl:for-each>							
					</xsl:otherwise>					
				</xsl:choose>
			
			</xsl:if>
			
			<xsl:apply-templates select="G_UTILMD_SG4"/>
	
		</nachricht>
		
		</xsl:for-each>		

		</fehler>

		</root>
	</xsl:template>


	<xsl:template match="G_UTILMD_SG4">
		<xsl:variable name="counterSegmente" select="count(preceding::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA']) + count(ancestor::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA'])"/>
		
		
		<!-- IDE prüfen -->
		<xsl:variable name="counterIDE" select="count(S_IDE)"/>

		<xsl:choose>
			<xsl:when test="$counterIDE=0">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente"/>
					<xsl:with-param name="code" select="13"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_IDE/D_7495"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'24'"/>		
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="S_IDE"/>
				</xsl:call-template>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_IDE/C_C206/D_7402"/>
					<xsl:with-param name="max" select="35"/>
					<xsl:with-param name="gruppenposition" select="3"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="S_EQD"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose> 
		
		<!-- IMD prüfen -->
		<xsl:variable name="counterIMD" select="count(S_IMD)"/>

		<xsl:for-each select="S_IMD">
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="C_C272/D_7081"/>
				<xsl:with-param name="max" select="3"/>
				<xsl:with-param name="wertebereich" select="'Z14,Z04'"/>		
				<xsl:with-param name="gruppenposition" select="3"/>
				<xsl:with-param name="elementposition" select="1"/>
				<xsl:with-param name="segmentknoten" select="."/>
			</xsl:call-template>		
			<xsl:choose>
				<xsl:when test="C_C272/D_7081='Z14'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C273/D_7009"/>
						<xsl:with-param name="max" select="17"/>
						<xsl:with-param name="wertebereich" select="'Z06,Z07'"/>		
						<xsl:with-param name="gruppenposition" select="4"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="C_C272/D_7081='Z04'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C273/D_7009"/>
						<xsl:with-param name="max" select="17"/>
						<xsl:with-param name="wertebereich" select="'Z01,Z02,Z03'"/>		
						<xsl:with-param name="gruppenposition" select="4"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>			
			</xsl:choose>	
		</xsl:for-each>

		<!-- DTM prüfen -->
		<xsl:variable name="counterDTM" select="count(S_DTM)"/>

		<xsl:for-each select="S_DTM">
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="C_C507/D_2005"/>
				<xsl:with-param name="max" select="3"/>
				<xsl:with-param name="wertebereich" select="'76,294,92,93,Z05,Z06,157,471,155,752,Z09,672,158,159,Z01,Z10,Z07,Z08'"/>		
				<xsl:with-param name="gruppenposition" select="2"/>
				<xsl:with-param name="elementposition" select="1"/>
				<xsl:with-param name="segmentknoten" select="."/>
			</xsl:call-template>
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="C_C507/D_2380"/>
				<xsl:with-param name="max" select="35"/>
				<xsl:with-param name="gruppenposition" select="2"/>
				<xsl:with-param name="elementposition" select="2"/>
				<xsl:with-param name="segmentknoten" select="."/>
			</xsl:call-template>			
			<xsl:choose>
				<xsl:when test="C_C507/D_2005='76' or C_C507/D_2005='92' or C_C507/D_2005='93' or C_C507/D_2005='Z05' or C_C507/D_2005='Z06' or C_C507/D_2005='471' or C_C507/D_2005='155' or C_C507/D_2005='Z07' or C_C507/D_2005='Z08'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C507/D_2379"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'102'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="3"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="C_C507/D_2005='294'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C507/D_2379"/>
						<xsl:with-param name="min" select="1"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'203'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="3"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>		
				<xsl:when test="C_C507/D_2005='157' or C_C507/D_2005='158' or C_C507/D_2005='159'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C507/D_2379"/>
						<xsl:with-param name="min" select="1"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'102,203'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="3"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>			
				<xsl:when test="C_C507/D_2005='752'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C507/D_2379"/>
						<xsl:with-param name="min" select="1"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'104,106'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="3"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>		
				<xsl:when test="C_C507/D_2005='Z09'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C507/D_2379"/>
						<xsl:with-param name="min" select="1"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'602'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="3"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>				
				<xsl:when test="C_C507/D_2005='672'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C507/D_2379"/>
						<xsl:with-param name="min" select="1"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'802'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="3"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>			
				<xsl:when test="C_C507/D_2005='Z01'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C507/D_2379"/>
						<xsl:with-param name="min" select="1"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'Z01'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="3"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>	
				<xsl:when test="C_C507/D_2005='Z10'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C507/D_2379"/>
						<xsl:with-param name="min" select="1"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'102,106'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="3"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>																			
			</xsl:choose>
				
		</xsl:for-each>
		
		
		<!-- STS prüfen -->
		<xsl:variable name="counterSTS" select="count(S_STS)"/>
					
		<xsl:for-each select="S_STS">
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="C_C601/D_9015"/>
				<xsl:with-param name="max" select="3"/>
				<xsl:with-param name="wertebereich" select="'7,Z17,E01,Z04,Z18,5,Z16,Z22'"/>		
				<xsl:with-param name="gruppenposition" select="2"/>
				<xsl:with-param name="elementposition" select="1"/>
				<xsl:with-param name="segmentknoten" select="."/>
			</xsl:call-template>
	
			<xsl:choose>
				<xsl:when test="C_C601/D_9015='5'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C555/D_4405"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'Z18,Z19,Z20,Z21,Z22,Z23'"/>		
						<xsl:with-param name="gruppenposition" select="3"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>																	
				</xsl:when>
				<xsl:when test="C_C601/D_9015='Z16'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C555/D_4405"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'Z26,Z27,Z28'"/>		
						<xsl:with-param name="gruppenposition" select="3"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>																	
				</xsl:when>
				<xsl:when test="C_C601/D_9015='7'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C556_1/D_9013"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'E01,E02,E03,E05,E06,Z15,Z26,Z33,Z36,Z37,Z38,Z39,Z40,Z41,Z69,ZB2,ZB3,ZC6,ZC7,ZC8,ZD0,ZD2,ZD9,ZE3,ZE4,ZE5,ZE6,ZE7,ZE8,ZE9,ZF0,ZF1,ZF2,ZF3,ZF4,ZF5,ZF6,ZF7,ZF8,ZG5,ZG6,ZG7,ZG8,ZG9,ZH0,ZH1,ZH2,ZJ7'"/>		
						<xsl:with-param name="gruppenposition" select="4"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>		
				<xsl:when test="C_C601/D_9015='Z17'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C556_1/D_9013"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'E01,E03'"/>		
						<xsl:with-param name="gruppenposition" select="4"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>	
				<xsl:when test="C_C601/D_9015='E01'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C556_1/D_9013"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'E11,E13,E14,E15,E17,Z01,Z07,Z08,Z09,Z12,Z14,Z15,Z29,Z30,Z34,Z35,Z43,Z44,Z48,Z49,Z50,E62,Z54,Z57,Z58,Z59,Z60,Z61,Z62,ZB6,ZB4,ZB5,ZC5,Z56,ZD3,ZD4,ZD5,ZD6,ZE0,ZE1,ZE2,ZF9,ZG0,ZG1,ZG2,ZG4,ZI3,ZI4,ZI5,ZI6,ZI7'"/>		
						<xsl:with-param name="gruppenposition" select="4"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>	
				<xsl:when test="C_C601/D_9015='Z04'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C555/D_4405"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'Z01,Z03,Z04,Z06'"/>		
						<xsl:with-param name="gruppenposition" select="3"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="C_C601/D_9015='Z18'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C555/D_4405"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'Z13,Z14'"/>		
						<xsl:with-param name="gruppenposition" select="3"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>	
				<xsl:when test="C_C601/D_9015='Z22'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C556_1/D_9013"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="gruppenposition" select="4"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C556_1/D_1131"/>
						<xsl:with-param name="max" select="17"/>
						<xsl:with-param name="wertebereich" select="'LAND'"/>		
						<xsl:with-param name="gruppenposition" select="4"/>
						<xsl:with-param name="elementposition" select="2"/>
						<xsl:with-param name="segmentknoten" select="."/>
						<xsl:with-param name="pflichtfeld" select="false()"/>
					</xsl:call-template>	
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C556_1/D_3055"/>
						<xsl:with-param name="max" select="17"/>
						<xsl:with-param name="wertebereich" select="'293'"/>		
						<xsl:with-param name="gruppenposition" select="4"/>
						<xsl:with-param name="elementposition" select="3"/>
						<xsl:with-param name="segmentknoten" select="."/>
						<xsl:with-param name="pflichtfeld" select="false()"/>
					</xsl:call-template>						
				</xsl:when>					
			</xsl:choose>	
			
		</xsl:for-each>		
		
		
		<!-- FTX prüfen -->
		<xsl:variable name="counterFTX" select="count(S_FTX)"/>
	
		<xsl:for-each select="S_FTX">
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="D_4451"/>
				<xsl:with-param name="max" select="3"/>
				<xsl:with-param name="wertebereich" select="'ACB,ABO,ADM,Z01'"/>		
				<xsl:with-param name="gruppenposition" select="2"/>
				<xsl:with-param name="segmentknoten" select="."/>
			</xsl:call-template>
			<xsl:choose>
				<xsl:when test="D_4451='ABO'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C107/D_4441"/>
						<xsl:with-param name="max" select="512"/>
						<xsl:with-param name="wertebereich" select="'Z03,Z04,Z05,Z06'"/>		
						<xsl:with-param name="gruppenposition" select="4"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
						<xsl:with-param name="pflichtfeld" select="false()"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="D_4451='ADM'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C107/D_4441"/>
						<xsl:with-param name="max" select="17"/>
						<xsl:with-param name="wertebereich" select="'Z01'"/>		
						<xsl:with-param name="gruppenposition" select="4"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>		
				<xsl:when test="D_4451='Z01'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C108/D_4440_1"/>
						<xsl:with-param name="max" select="512"/>
						<xsl:with-param name="wertebereich" select="'Z01'"/>		
						<xsl:with-param name="gruppenposition" select="5"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>		
				<xsl:when test="D_4451='ACB'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C108/D_4440_1"/>
						<xsl:with-param name="max" select="512"/>
						<xsl:with-param name="gruppenposition" select="5"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>
				</xsl:when>														
			</xsl:choose>
		</xsl:for-each>
		
		
		<!-- AGR prüfen -->
		<xsl:variable name="counterAGR" select="count(S_AGR)"/>
	
		<xsl:for-each select="S_AGR">
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="C_C543/D_7431"/>
				<xsl:with-param name="max" select="3"/>
				<xsl:with-param name="wertebereich" select="'11,E03,Z01,9'"/>		
				<xsl:with-param name="gruppenposition" select="2"/>
				<xsl:with-param name="elementposition" select="1"/>
				<xsl:with-param name="segmentknoten" select="."/>
			</xsl:call-template>
			<xsl:choose>
				<xsl:when test="C_C543/D_7431='11'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C543/D_7433"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'E01,E02'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="2"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>			
				</xsl:when>
				<xsl:when test="C_C543/D_7431='E03' or C_C543/D_7431='Z01'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C543/D_7433"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'E09,E10'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="2"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>			
				</xsl:when>		
				<xsl:when test="C_C543/D_7431='9'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C543/D_7433"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'Z04,Z06'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="2"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>			
				</xsl:when>							
			</xsl:choose>
		</xsl:for-each>
		
		<!-- LOC prüfen -->
		<xsl:variable name="counterLOC" select="count(S_LOC)"/>

		<xsl:for-each select="G_UTILMD_SG5/S_LOC">
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="D_3227"/>
				<xsl:with-param name="max" select="3"/>
				<xsl:with-param name="wertebereich" select="'Z02,Z03,Z05,107,237,172,231,Z07'"/>		
				<xsl:with-param name="gruppenposition" select="2"/>
				<xsl:with-param name="segmentknoten" select="."/>
			</xsl:call-template>
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="C_C517/D_3225"/>
				<xsl:with-param name="max" select="35"/>
				<xsl:with-param name="gruppenposition" select="3"/>
				<xsl:with-param name="elementposition" select="1"/>
				<xsl:with-param name="segmentknoten" select="."/>
			</xsl:call-template>					
			<xsl:choose>
				<xsl:when test="D_3227='Z02' or D_3227='Z03' or D_3227='Z05'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C517/D_3055_1"/>
						<xsl:with-param name="max" select="35"/>
						<xsl:with-param name="wertebereich" select="'89,293'"/>		
						<xsl:with-param name="gruppenposition" select="3"/>
						<xsl:with-param name="elementposition" select="3"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>						
				</xsl:when>
				<xsl:when test="D_3227='237'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="D_5479"/>
						<xsl:with-param name="max" select="1"/>
						<xsl:with-param name="wertebereich" select="'1,2,3,4,5,6'"/>		
						<xsl:with-param name="gruppenposition" select="6"/>
						<xsl:with-param name="segmentknoten" select="."/>
						<xsl:with-param name="pflichtfeld" select="false()"/>
						<xsl:with-param name="zeichenart" select="'n'"/>		
					</xsl:call-template>						
				</xsl:when>				
			</xsl:choose>
		</xsl:for-each>		
		
		<!-- RFF prüfen -->
		<xsl:variable name="counterRFF" select="count(G_UTILMD_SG6/S_RFF)"/>
		<xsl:variable name="counterRFF_Z13" select="count(G_UTILMD_SG6/S_RFF[C_C506/D_1153='Z13'])"/>
		
		<xsl:if test="$counterRFF_Z13=0">
			<xsl:call-template name="Fehler">
				<xsl:with-param name="segmentposition" select="$counterSegmente+$counterAGR+$counterDTM+$counterFTX+$counterIDE+$counterIMD+$counterLOC+$counterRFF"/>
				<xsl:with-param name="code" select="13"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:for-each select="G_UTILMD_SG6/S_RFF">
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="C_C506/D_1153"/>
				<xsl:with-param name="max" select="3"/>
				<xsl:with-param name="wertebereich" select="'Z13,TN,ACW,AAV,AVE,Z07,Z14'"/>		
				<xsl:with-param name="gruppenposition" select="2"/>
				<xsl:with-param name="elementposition" select="1"/>
				<xsl:with-param name="segmentknoten" select="."/>
			</xsl:call-template>
			<xsl:choose>
				<xsl:when test="C_C506/D_1153='Z13'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C506/D_1154"/>
						<xsl:with-param name="min" select="5"/>
						<xsl:with-param name="max" select="5"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="2"/>
						<xsl:with-param name="segmentknoten" select="."/>
						<xsl:with-param name="zeichenart" select="'n'"/>		
					</xsl:call-template>	
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C506/D_1154"/>
						<xsl:with-param name="max" select="70"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="2"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>				
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>	
		
		
		<!-- CCI prüfen -->
		<xsl:variable name="counterCCI" select="count(G_UTILMD_SG7/S_CCI)"/>
		
		<xsl:for-each select="G_UTILMD_SG7/S_CCI">
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="D_7059"/>
				<xsl:with-param name="max" select="3"/>
				<xsl:with-param name="wertebereich" select="'Z02,Z03,Z04,Z05,Z12,Z06,Z07'"/>		
				<xsl:with-param name="gruppenposition" select="2"/>
				<xsl:with-param name="segmentknoten" select="."/>
				<xsl:with-param name="pflichtfeld" select="false()"/>			
			</xsl:call-template>		
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="C_C240/D_7037"/>
				<xsl:with-param name="max" select="17"/>
				<xsl:with-param name="wertebereich" select="'E01,Z10,Z35,Z36,Z37,Z38,Z39,Z40,Z41,Z42,Z43,Z44,Z45,Z46,Z47,Z48,Z49,Z50,Z51,Z52,Z53,Z54,Z55,Z56,E02,Y01,E17,Z12,Z15,Z18,Z17,Z72,Y02'"/>		
				<xsl:with-param name="gruppenposition" select="4"/>
				<xsl:with-param name="elementposition" select="1"/>
				<xsl:with-param name="segmentknoten" select="."/>
				<xsl:with-param name="pflichtfeld" select="false()"/>			
			</xsl:call-template>				
			<xsl:choose>
				<xsl:when test="D_7059='Z02' or D_7059='Z03' or D_7059='Z04' or D_7059='Z05' or D_7059='Z12'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C240/D_7037"/>
						<xsl:with-param name="max" select="17"/>
						<xsl:with-param name="wertebereich" select="'E01,Z10'"/>		
						<xsl:with-param name="gruppenposition" select="4"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>					
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>	
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_3055_1"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'89,293'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="3"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>											
				</xsl:when>
				<xsl:when test="D_7059='Z06'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C240/D_7037"/>
						<xsl:with-param name="max" select="17"/>
						<xsl:with-param name="wertebereich" select="'Z35,Z36,Z37'"/>		
						<xsl:with-param name="gruppenposition" select="4"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>					
				</xsl:when>		
				<xsl:when test="D_7059='Z07'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C240/D_7037"/>
						<xsl:with-param name="max" select="17"/>
						<xsl:with-param name="wertebereich" select="'Z38,Z39,Z40,Z41,Z42,Z43,Z44,Z45,Z46,Z47,Z48,Z49,Z50,Z51,Z52,Z53,Z54,Z55,Z56'"/>		
						<xsl:with-param name="gruppenposition" select="4"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>					
				</xsl:when>								
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="C_C240/D_7037='E02'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'E01,E02,E14,E24,Z36,Z29'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>										
				</xsl:when>
				<xsl:when test="C_C240/D_7037='Y01'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'Y01,Y02,Y03'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>										
				</xsl:when>		
				<xsl:when test="C_C240/D_7037='E17'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'Z22'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>			
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7110_1"/>
						<xsl:with-param name="max" select="35"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="4"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>													
				</xsl:when>											
				<xsl:when test="C_C240/D_7037='Z12'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>										
				</xsl:when>	
				<xsl:when test="C_C240/D_7037='Z17'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C240/D_1131"/>
						<xsl:with-param name="max" select="17"/>
						<xsl:with-param name="wertebereich" select="'GABi-RLMNEV,GABi-RLMmT,GABi-RLMoT,ENTRY_H2,GABi-Entryso,GABi-Exitso,GABi-SLPana,GABi-SLPsyn,Entry Biogas'"/>		
						<xsl:with-param name="gruppenposition" select="4"/>
						<xsl:with-param name="elementposition" select="2"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>										
				</xsl:when>		
				<xsl:when test="C_C240/D_7037='Z72'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'E01,E02,E14,E24,Z36,Z29'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>												
				</xsl:when>	
				<xsl:when test="C_C240/D_7037='Y02'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'Y04,Y05'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>												
				</xsl:when>														
			</xsl:choose>
		</xsl:for-each>
		

		<xsl:apply-templates select="G_UTILMD_SG8"/>
		<xsl:apply-templates select="G_UTILMD_SG12"/>
		
	</xsl:template>
	
	
	<xsl:template match="G_UTILMD_SG8">
		<!-- SEQ prüfen -->
		<xsl:variable name="counterSEQ" select="count(S_SEQ)"/>
		
		<xsl:variable name="counterSegmente" select="count(preceding::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA']) + count(ancestor::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA'])"/>

		<xsl:choose>
			<xsl:when test="$counterSEQ=0">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente"/>
					<xsl:with-param name="code" select="13"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$counterSEQ &gt; 1">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente"/>
					<xsl:with-param name="code" select="35"/>
				</xsl:call-template>
			</xsl:when>			
			<xsl:otherwise>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_SEQ/D_1229"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'Z01,Z02,Z03,Z04,Z05,Z06,Z07,Z08,Z09,Z10,Z12,Z13,Z14'"/>		
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="S_SEQ"/>
				</xsl:call-template>
				<xsl:choose>
					<xsl:when test="S_SEQ/D_1229='Z01'">
						<xsl:for-each select="S_RFF">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1153"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'AVE,AUU,Z12,Z16'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>							
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1154"/>
								<xsl:with-param name="max" select="70"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>								
						</xsl:for-each>
						<xsl:for-each select="G_UTILMD_SG9/S_QTY">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C186/D_6063"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'Z10,265,Z08,31,Y02,Z07,Z09,11'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>				
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C186/D_6060"/>
								<xsl:with-param name="max" select="35"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
								<xsl:with-param name="zeichenart" select="'n'"/>		
							</xsl:call-template>												
							<xsl:choose>
								<xsl:when test="C_C186/D_6063='Z10'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="C_C186/D_6411"/>
										<xsl:with-param name="max" select="8"/>
										<xsl:with-param name="wertebereich" select="'KWT'"/>		
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="3"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>										
								</xsl:when>
								<xsl:when test="C_C186/D_6063='265'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="C_C186/D_6411"/>
										<xsl:with-param name="max" select="8"/>
										<xsl:with-param name="wertebereich" select="'Z16'"/>		
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="3"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>										
								</xsl:when>			
								<xsl:when test="C_C186/D_6063='Z08' or C_C186/D_6063='31' or C_C186/D_6063='Y02' or C_C186/D_6063='Z07' or C_C186/D_6063='Z09'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="C_C186/D_6411"/>
										<xsl:with-param name="max" select="8"/>
										<xsl:with-param name="wertebereich" select="'KWH'"/>		
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="3"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>										
								</xsl:when>		
								<xsl:when test="C_C186/D_6063='11'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="C_C186/D_6411"/>
										<xsl:with-param name="max" select="8"/>
										<xsl:with-param name="wertebereich" select="'P1'"/>		
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="3"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>										
								</xsl:when>																							
							</xsl:choose>			
						</xsl:for-each>	

						<xsl:for-each select="G_UTILMD_SG10/S_CCI">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="D_7059"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'Z01,15,Z15'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
								<xsl:with-param name="pflichtfeld" select="false()"/>								
							</xsl:call-template>								
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C240/D_7037"/>
								<xsl:with-param name="max" select="17"/>
								<xsl:with-param name="wertebereich" select="'Z30,Z31,Z70,Z71,Z32,Z67,Z68,Z69,Z21,E03,E04,Z16,Z34,Z83,Z84,Z78,Z85'"/>		
								<xsl:with-param name="gruppenposition" select="4"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
								<xsl:with-param name="pflichtfeld" select="false()"/>								
							</xsl:call-template>		
							<xsl:choose>
								<xsl:when test="D_7059='Z01'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="C_C240/D_7037"/>
										<xsl:with-param name="max" select="17"/>
										<xsl:with-param name="wertebereich" select="'Z30,Z31,Z70,Z71,Z32,Z67,Z68,Z69'"/>		
										<xsl:with-param name="gruppenposition" select="4"/>
										<xsl:with-param name="elementposition" select="1"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>										
								</xsl:when>
								<xsl:when test="D_7059='Z15'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="C_C240/D_7037"/>
										<xsl:with-param name="max" select="17"/>
										<xsl:with-param name="wertebereich" select="'Z30,Z31,Z70,Z71'"/>		
										<xsl:with-param name="gruppenposition" select="4"/>
										<xsl:with-param name="elementposition" select="1"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>										
								</xsl:when>								
								<xsl:when test="D_7059='15'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="C_C240/D_7037"/>
										<xsl:with-param name="max" select="17"/>
										<xsl:with-param name="wertebereich" select="'Z21'"/>		
										<xsl:with-param name="gruppenposition" select="4"/>
										<xsl:with-param name="elementposition" select="1"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>			
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
										<xsl:with-param name="max" select="3"/>
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="1"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>																	
								</xsl:when>	
								<xsl:when test="C_C240/D_7037='E04'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
										<xsl:with-param name="max" select="3"/>
										<xsl:with-param name="wertebereich" select="'E03,E04,E05,E06'"/>		
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="1"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>										
								</xsl:when>		
								<xsl:when test="C_C240/D_7037='Z16'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
										<xsl:with-param name="max" select="3"/>
										<xsl:with-param name="wertebereich" select="'Z28'"/>		
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="1"/>
										<xsl:with-param name="segmentknoten" select="."/>
								</xsl:call-template>			
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7110_1"/>
										<xsl:with-param name="max" select="35"/>
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="4"/>
										<xsl:with-param name="segmentknoten" select="."/>
										<xsl:with-param name="zeichenart" select="'n'"/>
									</xsl:call-template>										
								</xsl:when>	
								<xsl:when test="C_C240/D_7037='Z34'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
										<xsl:with-param name="max" select="3"/>
										<xsl:with-param name="wertebereich" select="'Z33,Z34,Z35,Z37,Z46'"/>		
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="1"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>										
								</xsl:when>			
								<xsl:when test="C_C240/D_7037='Z83'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
										<xsl:with-param name="max" select="3"/>
										<xsl:with-param name="wertebereich" select="'Z52,Z53,Z68'"/>		
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="1"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>										
								</xsl:when>
								<xsl:when test="C_C240/D_7037='Z84'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
										<xsl:with-param name="max" select="3"/>
										<xsl:with-param name="wertebereich" select="'Z54,Z55'"/>		
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="1"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>										
								</xsl:when>	
								<xsl:when test="C_C240/D_7037='Z78'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
										<xsl:with-param name="max" select="3"/>
										<xsl:with-param name="wertebereich" select="'Z40,Z41,Z42,Z43,Z59,Z60,Z67'"/>		
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="1"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>										
								</xsl:when>					
								<xsl:when test="C_C240/D_7037='E03'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
										<xsl:with-param name="max" select="3"/>
										<xsl:with-param name="wertebereich" select="'E03,E04,E05,E06,E07,E08,E09'"/>		
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="1"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>										
								</xsl:when>																																																																				
							</xsl:choose>
						</xsl:for-each>			
					</xsl:when>
					<xsl:when test="S_SEQ/D_1229='Z02'">
						<xsl:for-each select="S_RFF">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1153"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'AVE,MG,Z11'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>							
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1154"/>
								<xsl:with-param name="max" select="70"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>								
						</xsl:for-each>
						<xsl:for-each select="S_PIA">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="D_4347"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'5'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>							
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C212_1/D_7140_1"/>
								<xsl:with-param name="max" select="35"/>
								<xsl:with-param name="gruppenposition" select="3"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>		
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C212_1/D_7143_1"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'SRW'"/>		
								<xsl:with-param name="gruppenposition" select="3"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>														
						</xsl:for-each>						
						<xsl:for-each select="G_UTILMD_SG9/S_QTY">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C186/D_6063"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'79'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>				
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C186/D_6060"/>
								<xsl:with-param name="max" select="35"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
								<xsl:with-param name="zeichenart" select="'n'"/>		
							</xsl:call-template>
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C186/D_6411"/>
								<xsl:with-param name="max" select="8"/>
								<xsl:with-param name="wertebereich" select="'KWH'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="3"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>																				
						</xsl:for-each>
						<xsl:for-each select="G_UTILMD_SG9/S_DTM">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C507/D_2005"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'163,164'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C507/D_2380"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>																
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C507/D_2379"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'203'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="3"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>						
						</xsl:for-each>
						<xsl:for-each select="G_UTILMD_SG10/S_CCI">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="D_7059"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'11,Z10,Z17,Z83'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
								<xsl:with-param name="pflichtfeld" select="false()"/>								
							</xsl:call-template>								
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C240/D_7037"/>
								<xsl:with-param name="max" select="17"/>
								<xsl:with-param name="wertebereich" select="'Z33,Z63,Z59,Z60'"/>		
								<xsl:with-param name="gruppenposition" select="4"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
								<xsl:with-param name="pflichtfeld" select="false()"/>								
							</xsl:call-template>		
							<xsl:choose>
								<xsl:when test="D_7059='11'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="C_C240/D_7037"/>
										<xsl:with-param name="max" select="17"/>
										<xsl:with-param name="wertebereich" select="'Z33'"/>		
										<xsl:with-param name="gruppenposition" select="4"/>
										<xsl:with-param name="elementposition" select="1"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>			
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7110_1"/>
										<xsl:with-param name="max" select="35"/>
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="4"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>		
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7110_2"/>
										<xsl:with-param name="max" select="35"/>
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="5"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>																									
								</xsl:when>
								<xsl:when test="D_7059='Z10'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="C_C240/D_7037"/>
										<xsl:with-param name="max" select="17"/>
										<xsl:with-param name="wertebereich" select="'Z59,Z60'"/>		
										<xsl:with-param name="gruppenposition" select="4"/>
										<xsl:with-param name="elementposition" select="1"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>			
								</xsl:when>	
								<xsl:when test="D_7059='Z17'">
									<xsl:for-each select="../S_CAV">
										<xsl:call-template name="PruefeFeld">
											<xsl:with-param name="knoten" select="C_C889/D_7111"/>
											<xsl:with-param name="max" select="3"/>
											<xsl:with-param name="wertebereich" select="'Z56,Z57,Z61,Z62,Z63,Z64,Z65,Z66'"/>		
											<xsl:with-param name="gruppenposition" select="2"/>
											<xsl:with-param name="elementposition" select="1"/>
											<xsl:with-param name="segmentknoten" select="."/>
											<xsl:with-param name="pflichtfeld" select="false()"/>
										</xsl:call-template>										
									</xsl:for-each>																								
								</xsl:when>				
								<xsl:when test="D_7059='Z83'">
									<xsl:for-each select="../S_CAV">
										<xsl:call-template name="PruefeFeld">
											<xsl:with-param name="knoten" select="C_C889/D_7111"/>
											<xsl:with-param name="max" select="3"/>
											<xsl:with-param name="wertebereich" select="'Z52,Z53,Z68'"/>		
											<xsl:with-param name="gruppenposition" select="2"/>
											<xsl:with-param name="elementposition" select="1"/>
											<xsl:with-param name="segmentknoten" select="."/>
											<xsl:with-param name="pflichtfeld" select="false()"/>
										</xsl:call-template>										
									</xsl:for-each>																								
								</xsl:when>															
								<xsl:when test="C_C240/D_7037='Z63'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="C_C240/D_7037"/>
										<xsl:with-param name="max" select="17"/>
										<xsl:with-param name="wertebereich" select="'Z63'"/>		
										<xsl:with-param name="gruppenposition" select="4"/>
										<xsl:with-param name="elementposition" select="1"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>										
								</xsl:when>																									
							</xsl:choose>
						</xsl:for-each>			
					</xsl:when>
				<xsl:when test="S_SEQ/D_1229='Z07'">
						<xsl:for-each select="S_RFF">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1153"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'AVE,Z10'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>							
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1154"/>
								<xsl:with-param name="max" select="70"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>								
						</xsl:for-each>
						<xsl:for-each select="G_UTILMD_SG10/S_CCI">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C240/D_7037"/>
								<xsl:with-param name="max" select="17"/>
								<xsl:with-param name="wertebereich" select="'Z08,Z09'"/>		
								<xsl:with-param name="gruppenposition" select="4"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>		
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'KAS,SA,SAS,TA,TAS,TK,TKS,TS,TSS'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>		
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="S_SEQ/D_1229='Z10'">
						<xsl:for-each select="S_RFF">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1153"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'AVE,Z10'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>							
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1154"/>
								<xsl:with-param name="max" select="70"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>								
						</xsl:for-each>
						<xsl:for-each select="G_UTILMD_SG10/S_CCI">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="D_7059"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'Z13'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>	
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C240/D_7037"/>
								<xsl:with-param name="max" select="17"/>
								<xsl:with-param name="wertebereich" select="'Z65,Z66'"/>		
								<xsl:with-param name="gruppenposition" select="4"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>		
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="S_SEQ/D_1229='Z03'">
						<xsl:for-each select="S_RFF">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1153"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'AVE,Z14'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>							
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1154"/>
								<xsl:with-param name="max" select="70"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>								
						</xsl:for-each>
						<xsl:for-each select="G_UTILMD_SG10/S_CCI">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C240/D_7037"/>
								<xsl:with-param name="max" select="17"/>
								<xsl:with-param name="wertebereich" select="'E13,Z28,E12'"/>		
								<xsl:with-param name="gruppenposition" select="4"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>	
							<xsl:choose>
								<xsl:when test="C_C240/D_7037='E13'">
									<xsl:for-each select="../S_CAV">
										<xsl:call-template name="PruefeFeld">
											<xsl:with-param name="knoten" select="C_C889/D_7111"/>
											<xsl:with-param name="max" select="3"/>
											<xsl:with-param name="wertebereich" select="'AHZ,WSZ,LAZ,MAZ,DKZ,BGZ,TRZ,UGZ,WGZ,MRG,EHZ,MMA,IVA,Z30,ETZ,ZTZ,NTZ,ERZ,ZRZ,Z58'"/>		
											<xsl:with-param name="gruppenposition" select="2"/>
											<xsl:with-param name="elementposition" select="1"/>
											<xsl:with-param name="segmentknoten" select="."/>
											<xsl:with-param name="pflichtfeld" select="false()"/>
										</xsl:call-template>										
									</xsl:for-each>
								</xsl:when>
								<xsl:when test="C_C240/D_7037='Z28'">
									<xsl:for-each select="../S_CAV">
										<xsl:call-template name="PruefeFeld">
											<xsl:with-param name="knoten" select="C_C889/D_7111"/>
											<xsl:with-param name="max" select="3"/>
											<xsl:with-param name="wertebereich" select="'BKE,DPA,HUT,Z31,Z32'"/>		
											<xsl:with-param name="gruppenposition" select="2"/>
											<xsl:with-param name="elementposition" select="1"/>
											<xsl:with-param name="segmentknoten" select="."/>
											<xsl:with-param name="pflichtfeld" select="false()"/>
										</xsl:call-template>										
									</xsl:for-each>
								</xsl:when>
								<xsl:when test="C_C240/D_7037='E12'">
									<xsl:for-each select="../S_CAV">
										<xsl:call-template name="PruefeFeld">
											<xsl:with-param name="knoten" select="C_C889/D_7111"/>
											<xsl:with-param name="max" select="3"/>
											<xsl:with-param name="wertebereich" select="'AMR,MMR'"/>		
											<xsl:with-param name="gruppenposition" select="2"/>
											<xsl:with-param name="elementposition" select="1"/>
											<xsl:with-param name="segmentknoten" select="."/>
											<xsl:with-param name="pflichtfeld" select="false()"/>
										</xsl:call-template>										
									</xsl:for-each>
								</xsl:when>
							</xsl:choose>	
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="S_SEQ/D_1229='Z04'">
						<xsl:for-each select="S_RFF">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1153"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'MG'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>							
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1154"/>
								<xsl:with-param name="max" select="70"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>								
						</xsl:for-each>
						<xsl:for-each select="G_UTILMD_SG10/S_CCI">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C240/D_7037"/>
								<xsl:with-param name="max" select="17"/>
								<xsl:with-param name="wertebereich" select="'Z25'"/>		
								<xsl:with-param name="gruppenposition" select="4"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>	
							<xsl:for-each select="../S_CAV">
								<xsl:call-template name="PruefeFeld">
									<xsl:with-param name="knoten" select="C_C889/D_7111"/>
									<xsl:with-param name="max" select="3"/>
									<xsl:with-param name="wertebereich" select="'Z30,MIW,MPW,MBW,MUW'"/>		
									<xsl:with-param name="gruppenposition" select="2"/>
									<xsl:with-param name="elementposition" select="1"/>
									<xsl:with-param name="segmentknoten" select="."/>
								</xsl:call-template>		
								<xsl:if test="C_C889/D_7111='Z30'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="C_C889/D_7110_1"/>
										<xsl:with-param name="max" select="35"/>
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="4"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>							
								</xsl:if>								
							</xsl:for-each>							
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="S_SEQ/D_1229='Z09'">
						<xsl:for-each select="S_RFF">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1153"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'MG'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>							
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1154"/>
								<xsl:with-param name="max" select="70"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>								
						</xsl:for-each>
						<xsl:for-each select="G_UTILMD_SG10/S_CCI">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C240/D_7037"/>
								<xsl:with-param name="max" select="17"/>
								<xsl:with-param name="wertebereich" select="'Z64'"/>		
								<xsl:with-param name="gruppenposition" select="4"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>	
							<xsl:for-each select="../S_CAV">
								<xsl:call-template name="PruefeFeld">
									<xsl:with-param name="knoten" select="C_C889/D_7111"/>
									<xsl:with-param name="max" select="3"/>
									<xsl:with-param name="wertebereich" select="'Z30,DMU,TMU,ZMU'"/>		
									<xsl:with-param name="gruppenposition" select="2"/>
									<xsl:with-param name="elementposition" select="1"/>
									<xsl:with-param name="segmentknoten" select="."/>
								</xsl:call-template>		
								<xsl:if test="C_C889/D_7111='Z30'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="C_C889/D_7110_1"/>
										<xsl:with-param name="max" select="35"/>
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="4"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>							
								</xsl:if>								
							</xsl:for-each>
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="S_SEQ/D_1229='Z05'">
						<xsl:for-each select="S_RFF">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1153"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'MG'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>							
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1154"/>
								<xsl:with-param name="max" select="70"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>								
						</xsl:for-each>
						<xsl:for-each select="G_UTILMD_SG10/S_CCI">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C240/D_7037"/>
								<xsl:with-param name="max" select="17"/>
								<xsl:with-param name="wertebereich" select="'Z26'"/>		
								<xsl:with-param name="gruppenposition" select="4"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>	
							<xsl:for-each select="../S_CAV">
								<xsl:call-template name="PruefeFeld">
									<xsl:with-param name="knoten" select="C_C889/D_7111"/>
									<xsl:with-param name="max" select="3"/>
									<xsl:with-param name="wertebereich" select="'Z30,GSM,ETH,PLC,PST,DSL,LTE'"/>		
									<xsl:with-param name="gruppenposition" select="2"/>
									<xsl:with-param name="elementposition" select="1"/>
									<xsl:with-param name="segmentknoten" select="."/>
								</xsl:call-template>		
								<xsl:if test="C_C889/D_7111='Z30'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="C_C889/D_7110_1"/>
										<xsl:with-param name="max" select="35"/>
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="4"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>							
								</xsl:if>								
							</xsl:for-each>
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="S_SEQ/D_1229='Z06'">
						<xsl:for-each select="S_RFF">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1153"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'MG'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>							
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1154"/>
								<xsl:with-param name="max" select="70"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>								
						</xsl:for-each>
						<xsl:for-each select="G_UTILMD_SG10/S_CCI">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C240/D_7037"/>
								<xsl:with-param name="max" select="17"/>
								<xsl:with-param name="wertebereich" select="'Z27'"/>		
								<xsl:with-param name="gruppenposition" select="4"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>	
							<xsl:for-each select="../S_CAV">
								<xsl:call-template name="PruefeFeld">
									<xsl:with-param name="knoten" select="C_C889/D_7111"/>
									<xsl:with-param name="max" select="3"/>
									<xsl:with-param name="wertebereich" select="'Z30,RSU,TSU'"/>		
									<xsl:with-param name="gruppenposition" select="2"/>
									<xsl:with-param name="elementposition" select="1"/>
									<xsl:with-param name="segmentknoten" select="."/>
								</xsl:call-template>		
								<xsl:if test="C_C889/D_7111='Z30'">
									<xsl:call-template name="PruefeFeld">
										<xsl:with-param name="knoten" select="C_C889/D_7110_1"/>
										<xsl:with-param name="max" select="35"/>
										<xsl:with-param name="gruppenposition" select="2"/>
										<xsl:with-param name="elementposition" select="4"/>
										<xsl:with-param name="segmentknoten" select="."/>
									</xsl:call-template>							
								</xsl:if>								
							</xsl:for-each>
						</xsl:for-each>
					</xsl:when>		
					<xsl:when test="S_SEQ/D_1229='Z08'">
						<xsl:for-each select="S_RFF">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1153"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'MG'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>							
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1154"/>
								<xsl:with-param name="max" select="70"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>								
						</xsl:for-each>
						<xsl:for-each select="S_PIA">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="D_4347"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'Z01'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>							
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C212_1/D_7143_1"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'Z03,Z04,Z05'"/>		
								<xsl:with-param name="gruppenposition" select="3"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>														
						</xsl:for-each>		
						<xsl:for-each select="G_UTILMD_SG9/S_QTY">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C186/D_6063"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'Z11,Z12,Z13,Z14,Z15'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>				
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C186/D_6060"/>
								<xsl:with-param name="max" select="35"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
								<xsl:with-param name="zeichenart" select="'n'"/>		
							</xsl:call-template>												
						</xsl:for-each>							
						<xsl:for-each select="G_UTILMD_SG10/S_CCI">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C240/D_7059"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'Z11'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>	
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C240/D_7037"/>
								<xsl:with-param name="max" select="17"/>
								<xsl:with-param name="wertebereich" select="'Z61,Z62'"/>		
								<xsl:with-param name="gruppenposition" select="4"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>	
						</xsl:for-each>
					</xsl:when>		
					<xsl:when test="S_SEQ/D_1229='Z12'">
						<xsl:for-each select="G_UTILMD_SG9/S_QTY">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C186/D_6063"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'Z16'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>				
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C186/D_6060"/>
								<xsl:with-param name="max" select="35"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
								<xsl:with-param name="zeichenart" select="'n'"/>		
							</xsl:call-template>		
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C186/D_6411"/>
								<xsl:with-param name="max" select="8"/>
								<xsl:with-param name="wertebereich" select="'P1'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="3"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>																		
						</xsl:for-each>							
					</xsl:when>						
					<xsl:when test="S_SEQ/D_1229='Z13'">
						<xsl:for-each select="S_RFF">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1153"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'Z15'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>							
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1154"/>
								<xsl:with-param name="max" select="70"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>								
						</xsl:for-each>
						<xsl:for-each select="G_UTILMD_SG10/S_CCI">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C240/D_7037"/>
								<xsl:with-param name="max" select="17"/>
								<xsl:with-param name="wertebereich" select="'Z75'"/>		
								<xsl:with-param name="gruppenposition" select="4"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>	
							<xsl:for-each select="../S_CAV">
								<xsl:call-template name="PruefeFeld">
									<xsl:with-param name="knoten" select="C_C889/D_7111"/>
									<xsl:with-param name="max" select="3"/>
									<xsl:with-param name="wertebereich" select="'Z30'"/>		
									<xsl:with-param name="gruppenposition" select="2"/>
									<xsl:with-param name="elementposition" select="1"/>
									<xsl:with-param name="segmentknoten" select="."/>
								</xsl:call-template>		
								<xsl:call-template name="PruefeFeld">
									<xsl:with-param name="knoten" select="C_C889/D_7110_1"/>
									<xsl:with-param name="max" select="35"/>
									<xsl:with-param name="gruppenposition" select="2"/>
									<xsl:with-param name="elementposition" select="4"/>
									<xsl:with-param name="segmentknoten" select="."/>
								</xsl:call-template>							
							</xsl:for-each>
						</xsl:for-each>						
					</xsl:when>						
					<xsl:when test="S_SEQ/D_1229='Z14'">
						<xsl:for-each select="S_RFF">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1153"/>
								<xsl:with-param name="max" select="3"/>
								<xsl:with-param name="wertebereich" select="'MG,Z14'"/>		
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>							
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C506/D_1154"/>
								<xsl:with-param name="max" select="70"/>
								<xsl:with-param name="gruppenposition" select="2"/>
								<xsl:with-param name="elementposition" select="2"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>								
						</xsl:for-each>
						<xsl:for-each select="G_UTILMD_SG10/S_CCI">
							<xsl:call-template name="PruefeFeld">
								<xsl:with-param name="knoten" select="C_C240/D_7037"/>
								<xsl:with-param name="max" select="17"/>
								<xsl:with-param name="wertebereich" select="'Z76'"/>		
								<xsl:with-param name="gruppenposition" select="4"/>
								<xsl:with-param name="elementposition" select="1"/>
								<xsl:with-param name="segmentknoten" select="."/>
							</xsl:call-template>	
							<xsl:for-each select="../S_CAV">
								<xsl:call-template name="PruefeFeld">
									<xsl:with-param name="knoten" select="C_C889/D_7111"/>
									<xsl:with-param name="max" select="3"/>
									<xsl:with-param name="wertebereich" select="'Z30'"/>		
									<xsl:with-param name="gruppenposition" select="2"/>
									<xsl:with-param name="elementposition" select="1"/>
									<xsl:with-param name="segmentknoten" select="."/>
								</xsl:call-template>		
								<xsl:call-template name="PruefeFeld">
									<xsl:with-param name="knoten" select="C_C889/D_7110_1"/>
									<xsl:with-param name="max" select="35"/>
									<xsl:with-param name="gruppenposition" select="2"/>
									<xsl:with-param name="elementposition" select="4"/>
									<xsl:with-param name="segmentknoten" select="."/>
								</xsl:call-template>							
							</xsl:for-each>
						</xsl:for-each>						
					</xsl:when>						
									
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>			
		
		
	</xsl:template>

	
	<xsl:template match="G_UTILMD_SG12">
		<!-- SEQ prüfen -->
		<xsl:variable name="counterNAD" select="count(S_NAD)"/>
		
		<xsl:variable name="counterSegmente" select="count(preceding::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA']) + count(ancestor::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA'])"/>

		<xsl:choose>
			<xsl:when test="$counterNAD=0">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente"/>
					<xsl:with-param name="code" select="13"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$counterNAD &gt; 1">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente"/>
					<xsl:with-param name="code" select="35"/>
				</xsl:call-template>
			</xsl:when>			
			<xsl:otherwise>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_NAD/D_3035"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'UD,EO,DEB,SU,VY,DP,Z03,Z04,Z05'"/>		
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="S_NAD"/>
				</xsl:call-template>
				<xsl:choose>
					<xsl:when test="S_NAD/D_3035='UD'">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/C_C080/D_3036"/>
							<xsl:with-param name="max" select="70"/>
							<xsl:with-param name="gruppenposition" select="5"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>
						</xsl:call-template>				
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/C_C080/D_3045"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="wertebereich" select="'Z01,Z02'"/>		
							<xsl:with-param name="gruppenposition" select="5"/>
							<xsl:with-param name="elementposition" select="6"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>
						</xsl:call-template>										
					</xsl:when>					
					<xsl:when test="S_NAD/D_3035='Z04' or S_NAD/D_3035='DP'">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/C_C059/D_3042"/>
							<xsl:with-param name="max" select="35"/>
							<xsl:with-param name="gruppenposition" select="6"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>
						</xsl:call-template>					
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/D_3164"/>
							<xsl:with-param name="max" select="35"/>
							<xsl:with-param name="gruppenposition" select="7"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>
						</xsl:call-template>		
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/D_3251"/>
							<xsl:with-param name="max" select="17"/>
							<xsl:with-param name="gruppenposition" select="9"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>
						</xsl:call-template>	
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/D_3207"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="gruppenposition" select="10"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>
						</xsl:call-template>																				
					</xsl:when>						
					<xsl:when test="S_NAD/D_3035='EO' or S_NAD/D_3035='Z04'">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/C_C080/D_3036"/>
							<xsl:with-param name="max" select="70"/>
							<xsl:with-param name="gruppenposition" select="5"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>
						</xsl:call-template>		
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/D_3164"/>
							<xsl:with-param name="max" select="35"/>
							<xsl:with-param name="gruppenposition" select="7"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>
						</xsl:call-template>		
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/D_3251"/>
							<xsl:with-param name="max" select="17"/>
							<xsl:with-param name="gruppenposition" select="9"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>
						</xsl:call-template>	
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/D_3207"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="gruppenposition" select="10"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>
						</xsl:call-template>				
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/C_C080/D_3045"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="wertebereich" select="'Z01,Z02'"/>		
							<xsl:with-param name="gruppenposition" select="5"/>
							<xsl:with-param name="elementposition" select="6"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>
						</xsl:call-template>																	
					</xsl:when>									
					<xsl:when test="S_NAD/D_3035='DEB'">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/C_C082/D_3039"/>
							<xsl:with-param name="max" select="35"/>
							<xsl:with-param name="gruppenposition" select="3"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>		
						</xsl:call-template>		
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/C_C082/D_3055_1"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="wertebereich" select="'9,293,332'"/>		
							<xsl:with-param name="gruppenposition" select="3"/>
							<xsl:with-param name="elementposition" select="3"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>		
						</xsl:call-template>											
					</xsl:when>	
					<xsl:when test="S_NAD/D_3035='SU' or S_NAD/D_3035='VY'">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/C_C082/D_3039"/>
							<xsl:with-param name="max" select="35"/>
							<xsl:with-param name="gruppenposition" select="3"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>		
						</xsl:call-template>		
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/C_C082/D_3055_1"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="wertebereich" select="'9,293,332'"/>		
							<xsl:with-param name="gruppenposition" select="3"/>
							<xsl:with-param name="elementposition" select="3"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>		
						</xsl:call-template>											
					</xsl:when>	
					<xsl:when test="S_NAD/D_3035='Z03'">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/D_3251"/>
							<xsl:with-param name="max" select="17"/>
							<xsl:with-param name="gruppenposition" select="9"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>		
						</xsl:call-template>		
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/D_3207"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="gruppenposition" select="10"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>		
						</xsl:call-template>											
					</xsl:when>				
					<xsl:when test="S_NAD/D_3035='Z03' or S_NAD/D_3035='DP'">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/C_C058/D_3124"/>
							<xsl:with-param name="max" select="35"/>
							<xsl:with-param name="gruppenposition" select="4"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>		
							<xsl:with-param name="pflichtfeld" select="false()"/>		
						</xsl:call-template>		
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/C_C058/D_3124_2"/>
							<xsl:with-param name="max" select="35"/>
							<xsl:with-param name="gruppenposition" select="4"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>		
							<xsl:with-param name="pflichtfeld" select="false()"/>		
						</xsl:call-template>		
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/C_C058/D_3124_3"/>
							<xsl:with-param name="max" select="35"/>
							<xsl:with-param name="gruppenposition" select="4"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>		
							<xsl:with-param name="pflichtfeld" select="false()"/>		
						</xsl:call-template>		
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/C_C058/D_3124_4"/>
							<xsl:with-param name="max" select="35"/>
							<xsl:with-param name="gruppenposition" select="4"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>		
							<xsl:with-param name="pflichtfeld" select="false()"/>		
						</xsl:call-template>		
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="S_NAD/C_C058/D_3124_5"/>
							<xsl:with-param name="max" select="35"/>
							<xsl:with-param name="gruppenposition" select="4"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="S_NAD"/>		
							<xsl:with-param name="pflichtfeld" select="false()"/>		
						</xsl:call-template>		
					</xsl:when>			
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
		
		<xsl:for-each select="S_RFF">
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="C_C506/D_1153"/>
				<xsl:with-param name="max" select="3"/>
				<xsl:with-param name="wertebereich" select="'AVC,Z01,Z05,AVE,MG'"/>		
				<xsl:with-param name="gruppenposition" select="2"/>
				<xsl:with-param name="elementposition" select="1"/>
				<xsl:with-param name="segmentknoten" select="."/>		
			</xsl:call-template>	
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="C_C506/D_1154"/>
				<xsl:with-param name="max" select="70"/>
				<xsl:with-param name="gruppenposition" select="2"/>
				<xsl:with-param name="elementposition" select="2"/>
				<xsl:with-param name="segmentknoten" select="."/>		
			</xsl:call-template>									
		</xsl:for-each>
	</xsl:template>
	
	<!-- Felderprüfungen -->
	<xsl:template name="PruefeFeld">
			
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="segment" required="no"/>
		<xsl:param name="zeichenart" required="no"/>		
		<xsl:param name="wertebereich" required="no"/>
		<xsl:param name="pflichtfeld" required="no" as="xs:boolean" select="true()"/>
		<xsl:param name="min" required="no"/>
		<xsl:param name="max" required="no"/>
		<xsl:param name="gruppenposition" required="yes"/>
		<xsl:param name="elementposition" required="no"/>
		<xsl:param name="segmentknoten" required="no"/>
				
						<xsl:message>prüfe feld - knoten:<xsl:value-of select="name($knoten)"/>-wert:<xsl:value-of select="$knoten"/> </xsl:message>

		<xsl:variable name="trennzeichen" select="/EDIFACTINTERCHANGE/S_UNA/D_UNA3"/>

		<xsl:variable name="code" as="xs:string">
			<xsl:choose>
				<!-- 13 Fehlt -->
				<xsl:when test="(not($knoten) or $knoten='') and $pflichtfeld=true()">
					<xsl:value-of select="13"/>
				</xsl:when>
				<xsl:when test="$knoten">
					<xsl:choose>
						
						<!-- 12 Ungültiger Wert -->
						<xsl:when test="$wertebereich and not(exists(tokenize($wertebereich, ',')[. = $knoten]))">
							<xsl:value-of select="12"/>
						</xsl:when>			
						<!-- 38 Fehlende Ziffer vor dem Dezimalzeichen -->
						<xsl:when test="$zeichenart='n' and (substring($knoten, 1, 1) = '.' or substring($knoten, 1, 1) = ',' )">
							<xsl:value-of select="38"/>
						</xsl:when>		
						<!-- 37 Ungültige Zeichenart (numerisch) -->
						<xsl:when test="$zeichenart='n' and not($knoten castable as xs:double)">
							<xsl:value-of select="37"/>
						</xsl:when>		
						<!-- 39 Datenelement zu lang -->
						<xsl:when test="$max and string-length($knoten) &gt; number($max)">
							<xsl:value-of select="39"/>
						</xsl:when>		
						<!-- 40 Datenelement zu kurz -->
						<xsl:when test="$max and string-length($knoten) &lt; number($min)">
							<xsl:value-of select="40"/>
						</xsl:when>					
						<!-- Feld in Ordnung -->
						<xsl:otherwise>
							<xsl:value-of select="0"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>	
				<xsl:otherwise>
					<xsl:value-of select="0"/>
				</xsl:otherwise>				
			</xsl:choose>	
				
		</xsl:variable>
		
		
		<xsl:if test="$code != '0'">
		
	
			<xsl:choose>
				<xsl:when test="$segment='UNA' or $segment='UNB' or $segment='UNZ'">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="$code"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="gruppenposition" select="$gruppenposition"/>
						<xsl:with-param name="elementposition" select="$elementposition"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$segment='UNH' or $segment='UNT'">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="referenzUNH" select="$knoten/ancestor::*[substring(name(), 1, 2)='M_']/S_UNH/D_0062"/>
						<xsl:with-param name="code" select="$code"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="gruppenposition" select="$gruppenposition"/>
						<xsl:with-param name="elementposition" select="$elementposition"/>
					</xsl:call-template>
				</xsl:when>				
				<xsl:otherwise>
			
					<xsl:call-template name="Fehler">
						<xsl:with-param name="referenzUNH" select="$segmentknoten/ancestor::*[substring(name(), 1, 2)='M_']/S_UNH/D_0062"/>
						<xsl:with-param name="code" select="$code"/>
						<xsl:with-param name="segmentposition" select="count($segmentknoten/preceding::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA']) + count($segmentknoten/ancestor::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA'])+1"/>
						<xsl:with-param name="gruppenposition" select="$gruppenposition"/>
						<xsl:with-param name="elementposition" select="$elementposition"/>
					</xsl:call-template>			
				</xsl:otherwise>
			</xsl:choose>

		</xsl:if>
	</xsl:template>

		<!-- Fehler ausgeben -->
	<xsl:template name="Fehler">

		<xsl:param name="referenzUNH"/>		
		<xsl:param name="code"/>
		<xsl:param name="segment"/>
		<xsl:param name="segmentposition"/>
		<xsl:param name="gruppenposition"/>
		<xsl:param name="elementposition"/>
		
						<xsl:message>fehlertemplate</xsl:message>

		<xsl:variable name="fehlerart">
			<xsl:choose>
				<xsl:when test="$segment='UNA' or $segment='UNB' or $segment='UNZ'">
					<xsl:value-of select="'UCI'"/>
				</xsl:when>
				<xsl:when test="$segment='UNH' or $segment='UNT'">
					<xsl:value-of select="'UCM'"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="$gruppenposition">
							<xsl:value-of select="'UCD'"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="'UCS'"/>
						</xsl:otherwise>										
					</xsl:choose>
				</xsl:otherwise>										
			</xsl:choose>
		</xsl:variable>
		
		
		
		<xsl:element name="{$fehlerart}">
			<referenzUNH><xsl:value-of select="$referenzUNH"/></referenzUNH>
			<code><xsl:value-of select="$code"/></code>
			<segment><xsl:value-of select="$segment"/></segment>
			<segmentposition><xsl:value-of select="$segmentposition"/></segmentposition>		
			<gruppenposition><xsl:value-of select="$gruppenposition"/></gruppenposition>
			<elementposition><xsl:value-of select="$elementposition"/></elementposition>
		</xsl:element>
		
		
	</xsl:template>
	
</xsl:stylesheet>
